import copy
import json
import os.path
import multiprocessing
from .jobs_history_journal import JobsHistory
from .db_connection_window import DatabaseConnectionWindow
from ...core.logger import get_module_logger

try:
    from PyQt6 import QtGui
    from PyQt6.QtGui import QIcon
    from PyQt6.QtGui import QAction
    from PyQt6.QtCore import pyqtSignal, pyqtSlot, Qt
    from PyQt6.QtSql import QSqlDatabase
    from PyQt6.QtWidgets import (
    QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea, QMessageBox,
    QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem, QTextEdit,
    QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    pyqt_version = 6
except ImportError:
    from PyQt5 import QtGui
    from PyQt5.QtGui import QIcon
    from PyQt5.QtGui import QAction
    from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt
    from PyQt5.QtSql import QSqlDatabase
    from PyQt5.QtWidgets import (
    QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea, QMessageBox,
    QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem, QTextEdit,
    QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    pyqt_version = 5


from ...utils import utils
from .configurer_tabs import src_tab, detector_tab, handler_tab, visualizer_tab, database_tab, tracker_tab, events_tab
from ... import process


class SaveWindow(QWidget):
    save_params_signal = pyqtSignal(str)

    def __init__(self):
        super().__init__()
        self.h_layout = QHBoxLayout()
        self.save_button = QPushButton('Save parameters', self)
        self.save_button.clicked.connect(self._save_data)
        self.file_name = QLabel('Enter file name')
        self.file_name_edit = QTextEdit()
        self.file_name_edit.setText('.json')
        self.file_name_edit.setFixedHeight(self.save_button.geometry().height())
        self.h_layout.addWidget(self.file_name_edit)
        self.h_layout.addWidget(self.save_button)
        self.setLayout(self.h_layout)

    @pyqtSlot()
    def _save_data(self):
        file_name = self.file_name_edit.toPlainText()
        if not file_name.strip('.json'):
            file_name = 'temp.json'
        self.save_params_signal.emit(file_name)
        self.close()


class ConfigurerMainWindow(QMainWindow):
    display_zones_signal = pyqtSignal(dict)
    add_zone_signal = pyqtSignal(int)

    def __init__(self, config_file_name, win_width, win_height):
        super().__init__()
        self.logger = get_module_logger("configurer_window")
        self.config_file_name = config_file_name
        self.setWindowTitle("EvilEye Configurer")
        self.resize(win_width, win_height)

        self.is_db_connected = False

        file_path = self.config_file_name  # 'configurer/initial_config.json'
        full_path = os.path.join(utils.get_project_root(), file_path)
        with open(full_path, 'r+') as params_file:
            config_params = json.load(params_file)

        with open(os.path.join(utils.get_project_root(), "evileye", "database_config.json"), 'r+') as database_config_file:
            database_params = json.load(database_config_file)

        try:
            with open("credentials.json") as creds_file:
                self.credentials = json.load(creds_file)
        except FileNotFoundError as ex:
            pass

        database_creds = self.credentials.get("database", None)
        if not database_creds:
            database_creds = dict()

        try:
            with open(os.path.join(utils.get_project_root(), "evileye", "database_config.json")) as data_config_file:
                self.database_config = json.load(data_config_file)
        except FileNotFoundError as ex:
            self.database_config = dict()
            self.database_config["database"] = dict()

        database_creds["user_name"] = database_creds.get("user_name", "evil_eye_user")
        database_creds["password"] = database_creds.get("password", "")
        database_creds["database_name"] = database_creds.get("database_name", "evil_eye_db")
        database_creds["host_name"] = database_creds.get("host_name", "localhost")
        database_creds["port"] = database_creds.get("port", 5432)
        database_creds["admin_user_name"] = database_creds.get("admin_user_name", "postgres")
        database_creds["admin_password"] = database_creds.get("admin_password", "")

        self.database_config["database"]["user_name"] = self.database_config["database"].get("user_name", database_creds["user_name"])
        self.database_config["database"]["password"] = self.database_config["database"].get("password", database_creds["password"])
        self.database_config["database"]["database_name"] = self.database_config["database"].get("database_name", database_creds["database_name"])
        self.database_config["database"]["host_name"] = self.database_config["database"].get("host_name", database_creds["host_name"])
        self.database_config["database"]["port"] = self.database_config["database"].get("port", database_creds["port"])
        self.database_config["database"]["admin_user_name"] = self.database_config["database"].get("admin_user_name", database_creds["admin_user_name"])
        self.database_config["database"]["admin_password"] = self.database_config["database"].get("admin_password", database_creds["admin_password"])

        self.params = config_params
        self.default_src_params = self.params['sources'][0]
        self.default_det_params = self.params['detectors'][0]
        self.default_track_params = self.params['trackers'][0]
        self.default_vis_params = self.params['visualizer']
        self.default_db_params = self.database_config['database']
        self.default_events_params = self.params['events_detectors']
        self.default_handler_params = self.params['objects_handler']
        self.config_result = copy.deepcopy(config_params)

        self.src_hist_clicked = False
        self.jobs_hist_clicked = False

        self.proj_root = utils.get_project_root()
        self.hor_layouts = {}
        self.det_button = None
        self.track_buttons = []
        self.split_check_boxes = []
        self.botsort_check_boxes = []
        self.coords_edits = []
        self.src_counter = 0
        self.jobs_history = None
        # self.db_window = DatabaseConnectionWindow(self.database_config)
        # self.db_window.database_connection_signal.connect(self._open_history)
        # self.db_window.setVisible(False)

        self.save_win = SaveWindow()
        self.save_win.save_params_signal.connect(self._save_params)

        self.tab_params = {}  # Словарь для сопоставления полей интерфейса с полями json-файла

        self._setup_tabs()

        self.main_widget = QWidget()
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_area.setWidget(self.tabs)
        self._create_actions()
        self._connect_actions()
        self.menu_height = 0
        self._create_menu_bar()

        self.run_flag = False

        self.toolbar_width = 0
        self._create_toolbar()
        self._connect_to_db()

        self.vertical_layout = QVBoxLayout()
        self.vertical_layout.setAlignment(Qt.AlignmentFlag.AlignLeft | Qt.AlignmentFlag.AlignTop)
        self.setCentralWidget(self.scroll_area)
        self.result_filename = None
        multiprocessing.set_start_method('spawn')

    def _setup_tabs(self):
        self.tabs = QTabWidget()
        self.tabs.addTab(src_tab.SourcesTab(self.params['sources'], self.credentials, parent=self), 'Sources')
        self.tabs.addTab(detector_tab.DetectorTab(self.params['detectors']), 'Detectors')
        self.tabs.addTab(tracker_tab.TrackerTab(self.params['trackers']), 'Trackers')
        self.tabs.addTab(handler_tab.HandlerTab(self.params, self.database_config), 'Objects handler')
        self.tabs.addTab(database_tab.DatabaseTab(self.params, self.database_config), 'Database')
        self.tabs.addTab(visualizer_tab.VisualizerTab(self.params), 'Visualizer')
        self.tabs.addTab(events_tab.EventsTab(self.params), 'Events')
        self.sections = ['sources', 'detectors', 'trackers', 'objects_handler',
                         'database', 'visualizer', 'events_detectors']

        source_tab = self.tabs.widget(0)
        source_tab.connection_win_signal.connect(self._check_db_connection)
        det_tab = self.tabs.widget(1)
        track_tab = self.tabs.widget(2)
        det_tab.tracker_enabled_signal.connect(track_tab.enable_add_tracker_button)

        self.tab_params['sources'] = self.tabs.widget(0)
        self.tab_params['detectors'] = self.tabs.widget(1)
        self.tab_params['trackers'] = self.tabs.widget(2)
        self.tab_params['objects_handler'] = self.tabs.widget(3)
        self.tab_params['database'] = self.tabs.widget(4)
        self.tab_params['visualizer'] = self.tabs.widget(5)
        self.tab_params['events_detectors'] = self.tabs.widget(6)

    def _create_menu_bar(self):
        menu = self.menuBar()
        edit_menu = QMenu('&Edit', self)
        open_menu = QMenu('&Open', self)
        run_menu = QMenu('&Run', self)
        menu.addMenu(open_menu)
        menu.addMenu(edit_menu)
        menu.addMenu(run_menu)
        edit_menu.addAction(self.save_params)
        open_menu.addAction(self.open_jobs_history)
        run_menu.addAction(self.start_app)
        self.menu_height = edit_menu.frameGeometry().height()

    def _create_toolbar(self):
        toolbar = QToolBar('Edit', self)
        self.addToolBar(Qt.ToolBarArea.RightToolBarArea, toolbar)
        toolbar.addAction(self.save_params)
        toolbar.addAction(self.open_jobs_history)
        toolbar.addAction(self.start_app)
        self.toolbar_width = toolbar.frameGeometry().width()

    def _create_actions(self):  # Создание кнопок-действий
        self.save_params = QAction('&Save parameters', self)
        self.save_params.setIcon(QIcon(os.path.join(utils.get_project_root(), 'icons', 'save_icon.svg')))
        self.open_jobs_history = QAction('&Open history', self)
        self.start_app = QAction('&Run app', self)
        self.start_app.setIcon(QIcon(os.path.join(utils.get_project_root(), 'icons', 'run_app.svg')))
        icon_path = os.path.join(utils.get_project_root(), 'icons', 'journal.svg')
        self.open_jobs_history.setIcon(QIcon(icon_path))

    def _connect_actions(self):
        self.save_params.triggered.connect(self._open_save_win)
        self.open_jobs_history.triggered.connect(self._check_db_connection)
        self.start_app.triggered.connect(self._prepare_running)

    @pyqtSlot()
    def _prepare_running(self):
        self.run_flag = True
        self._open_save_win()

    def _run_app(self):
        self.new_process = multiprocessing.Process(target=process.start_app, args=(self.result_filename,))
        self.new_process.start()
        self.new_process.join()

    @pyqtSlot()
    def _open_save_win(self):
        self.save_win.show()

    @pyqtSlot(str)
    def _save_params(self, file_name):
        self._process_params_strings()
        self.result_filename = os.path.join(utils.get_project_root(), file_name)
        with open(self.result_filename, 'w') as file:
            json.dump(self.config_result, file, indent=4)

        if self.run_flag:
            self.save_win.close()
            self._run_app()

    @pyqtSlot()
    def _check_db_connection(self):
        sender = self.sender()
        if isinstance(sender, QAction):
            self.jobs_hist_clicked = True
            self.src_hist_clicked = False
            if self.is_db_connected:
                self._open_history()
            else:
                self._connect_to_db()
                # if self.db_window.isVisible():
                #     self.db_window.setVisible(False)
                # else:
                #     self.db_window.setVisible(True)
        else:
            self.src_hist_clicked = True
            self.jobs_hist_clicked = False
            if self.is_db_connected:
                self.tabs.widget(0).open_src_list()
            else:
                self._connect_to_db()
                # if self.db_window.isVisible():
                #     self.db_window.setVisible(False)
                # else:
                #     self.db_window.setVisible(True)

    @pyqtSlot()
    def _open_history(self):
        if self.jobs_hist_clicked:
            if not self.jobs_history:
                self.jobs_history = JobsHistory()
                self.jobs_history.setVisible(False)

            if self.jobs_history.isVisible():
                self.jobs_history.setVisible(False)
            else:
                self.jobs_history.setVisible(True)

        if self.src_hist_clicked:
            self.tabs.widget(0).open_src_list()

    def _process_params_strings(self):
        configs = []
        src_config = self.tab_params['sources'].get_params()
        configs.append(('sources', src_config))
        det_config = self.tab_params['detectors'].get_params()
        configs.append(('detectors', det_config))
        track_config = self.tab_params['trackers'].get_params()
        configs.append(('trackers', track_config))
        vis_config = self.tab_params['visualizer'].get_params()
        configs.append(('visualizer', vis_config))
        handler_config = self.tab_params['objects_handler'].get_params()
        configs.append(('objects_handler', handler_config))
        events_config = self.tab_params['events_detectors'].get_params()
        configs.append(('events_detectors', events_config))
        self._create_resulting_config(configs, self.params)

    def _create_resulting_config(self, configs, default_config):
        for section_config in configs:
            section_name = section_config[0]
            section_params = section_config[1]
            self.config_result[section_name] = section_params

    def _connect_to_db(self):
        db_params = self.database_config['database']
        db = QSqlDatabase.addDatabase("QPSQL", 'jobs_conn')
        db.setHostName(db_params['host_name'])
        db.setDatabaseName(db_params['database_name'])
        db.setUserName(db_params['user_name'])
        db.setPassword(db_params['password'])
        db.setPort(db_params['port'])
        if not db.open():
            QMessageBox.critical(
                None,
                "Connection error",
                str(db.lastError().text()),
            )
            self.is_db_connected = False
        else:
            self.is_db_connected = True

    def closeEvent(self, event):
        for tab_idx in range(self.tabs.count()):
            tab = self.tabs.widget(tab_idx)
            tab.close()
        # self.db_window.close()
        self.logger.info('DB jobs_conn removed')
        QSqlDatabase.removeDatabase('jobs_conn')
        QApplication.closeAllWindows()
        event.accept()

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        super().resizeEvent(event)



import os
import json
import datetime
from typing import Dict, List

try:
    from PyQt6.QtCore import Qt, pyqtSlot
    from PyQt6.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QPushButton,
        QHeaderView, QComboBox, QTableWidget, QTableWidgetItem, QFileDialog, QStyledItemDelegate
    )
    from PyQt6.QtGui import QPixmap, QPainter, QPen, QColor, QBrush
    from PyQt6.QtCore import QSize, QTimer
    pyqt_version = 6
except ImportError:
    from PyQt5.QtCore import Qt, pyqtSlot
    from PyQt5.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QPushButton,
        QHeaderView, QComboBox, QTableWidget, QTableWidgetItem, QFileDialog, QStyledItemDelegate
    )
    from PyQt5.QtGui import QPixmap, QPainter, QPen, QColor, QBrush
    from PyQt5.QtCore import QSize, QTimer
    pyqt_version = 5

from .journal_data_source_json import JsonLabelJournalDataSource
from ..core.logger import get_module_logger
import logging


class ImageDelegate(QStyledItemDelegate):
    def __init__(self, parent=None, base_dir=None, logger_name: str | None = None, parent_logger: logging.Logger | None = None):
        super().__init__(parent)
        base_name = "evileye.image_delegate"
        full_name = f"{base_name}.{logger_name}" if logger_name else base_name
        self.logger = parent_logger or logging.getLogger(full_name)
        self.base_dir = base_dir
        self.preview_width = 300
        self.preview_height = 150

    def paint(self, painter, option, index):
        if not index.isValid():
            return
            
        # Get event data from the row
        table = self.parent()
        if not table:
            return
            
        row = index.row()
        if row >= table.rowCount():
            return
            
        # Get image filename from the row (Preview or Lost preview column)
        img_filename_item = table.item(row, index.column())  # Use current column
        
        if not img_filename_item:
            return
            
        img_path = img_filename_item.text()
        
        # If no image path, just return (empty cell)
        if not img_path:
            return
        
        # Use image path directly from JSON
        if not img_path:
            return
            
        if not os.path.exists(img_path):
            # Debug: print missing image path
            self.logger.warning(f"Image not found: {img_path}")
            return
            
        # Load and scale image
        pixmap = QPixmap(img_path)
        if pixmap.isNull():
            return
            
        pixmap = pixmap.scaled(self.preview_width, self.preview_height, 
                             Qt.AspectRatioMode.KeepAspectRatio, 
                             Qt.TransformationMode.SmoothTransformation)
        
        # Draw image only - no bounding boxes
        painter.drawPixmap(option.rect, pixmap)

    def sizeHint(self, option, index):
        return QSize(self.preview_width, self.preview_height)


class DateTimeDelegate(QStyledItemDelegate):
    def __init__(self, parent=None):
        super().__init__(parent)

    def displayText(self, value, locale) -> str:
        """Format datetime to show only seconds precision"""
        try:
            if isinstance(value, str):
                # Parse ISO format datetime string
                if 'T' in value:
                    # ISO format: 2025-09-01T17:30:45.123456
                    dt = datetime.datetime.fromisoformat(value.replace('Z', '+00:00'))
                    return dt.strftime('%Y-%m-%d %H:%M:%S')
                else:
                    # Already formatted or other format
                    return value
            return str(value)
        except Exception as e:
            self.logger.error(f"Time formatting error: {e}")
            return str(value)


class ImageWindow(QLabel):
    def __init__(self, image_path, box=None, parent=None):
        super().__init__(parent)
        self.setWindowTitle('Image')
        self.setFixedSize(900, 600)
        self.image_path = image_path
        
        # Load image
        pixmap = QPixmap(image_path)
        if pixmap.isNull():
            self.logger.error(f"Image loading error: {image_path}")
            return
            
        # Scale image to fit window
        pixmap = pixmap.scaled(self.width(), self.height(), 
                              Qt.AspectRatioMode.KeepAspectRatio, 
                              Qt.TransformationMode.SmoothTransformation)
        
        # Draw bounding box if provided
        if box:
            painter = QPainter(pixmap)
            pen = QPen(QColor(0, 255, 0), 2)  # Green color
            painter.setPen(pen)
            
            # Convert normalized coordinates to pixel coordinates
            x = int(box[0] * pixmap.width())
            y = int(box[1] * pixmap.height())
            w = int(box[2] * pixmap.width())
            h = int(box[3] * pixmap.height())
            
            painter.drawRect(x, y, w, h)
            painter.end()
        
        # Create label and set pixmap
        self.label = QLabel()
        self.label.setPixmap(pixmap)
        
        # Setup layout
        self.layout = QVBoxLayout()
        self.layout.addWidget(self.label)
        self.setLayout(self.layout)

    def mouseDoubleClickEvent(self, event):
        self.hide()
        event.accept()


class EventsJournalJson(QWidget):
    def __init__(self, base_dir: str, parent=None, logger_name: str | None = None, parent_logger: logging.Logger | None = None):
        super().__init__(parent)
        base_name = "evileye.events_journal_json"
        full_name = f"{base_name}.{logger_name}" if logger_name else base_name
        self.logger = parent_logger or logging.getLogger(full_name)
        self.setWindowTitle('Events journal (JSON)')
        self.base_dir = base_dir
        self.ds = JsonLabelJournalDataSource(base_dir)
        self.page = 0
        self.page_size = 50
        self.filters: Dict = {}
        
        # Store last data hash for efficient updates
        self.last_data_hash = None
        self.is_visible = False
        
        # Real-time update timer
        self.update_timer = QTimer()
        self.update_timer.timeout.connect(self._check_for_updates)
        self.update_timer.start(500)  # Check every 0.5 seconds for better responsiveness

        self._build_ui()
        self._reload_dates()
        self._reload_table()

    def _build_ui(self):
        self.layout = QVBoxLayout()

        toolbar = QHBoxLayout()
        # Remove the directory selection button - use base_dir directly
        # self.btn_open_dir = QPushButton('Open images dir')
        # self.btn_open_dir.clicked.connect(self._choose_dir)
        # toolbar.addWidget(self.btn_open_dir)

        self.cmb_date = QComboBox()
        self.cmb_date.currentTextChanged.connect(self._on_date_changed)
        toolbar.addWidget(self.cmb_date)

        self.cmb_type = QComboBox()
        self.cmb_type.addItems(['All', 'found', 'lost'])
        self.cmb_type.currentTextChanged.connect(self._on_filter_changed)
        toolbar.addWidget(self.cmb_type)

        self.layout.addLayout(toolbar)

        # Use database journal structure: Name, Event, Information, Time, Time lost, Preview, Lost preview
        self.table = QTableWidget(0, 7)
        self.table.setHorizontalHeaderLabels(['Name', 'Event', 'Information', 'Time', 'Time lost', 'Preview', 'Lost preview'])
        h = self.table.horizontalHeader()
        h.setSectionResizeMode(0, QHeaderView.ResizeMode.ResizeToContents)
        h.setSectionResizeMode(1, QHeaderView.ResizeMode.ResizeToContents)
        h.setSectionResizeMode(2, QHeaderView.ResizeMode.ResizeToContents)
        h.setSectionResizeMode(3, QHeaderView.ResizeMode.ResizeToContents)
        h.setSectionResizeMode(4, QHeaderView.ResizeMode.ResizeToContents)
        h.setSectionResizeMode(5, QHeaderView.ResizeMode.Fixed)
        h.setSectionResizeMode(6, QHeaderView.ResizeMode.Fixed)
        h.setDefaultSectionSize(300)  # Set default size for image columns
        self.layout.addWidget(self.table)

        # Set up image delegate for image columns (Preview and Lost preview)
        self.image_delegate = ImageDelegate(self.table, self.base_dir, logger_name="image_delegate", parent_logger=self.logger)
        self.table.setItemDelegateForColumn(5, self.image_delegate)  # Preview
        self.table.setItemDelegateForColumn(6, self.image_delegate)  # Lost preview

        # Set up datetime delegate for time columns
        self.datetime_delegate = DateTimeDelegate(self.table)
        self.table.setItemDelegateForColumn(3, self.datetime_delegate)  # Time
        self.table.setItemDelegateForColumn(4, self.datetime_delegate)  # Time lost

        # Connect double click signal - use cellDoubleClicked for QTableWidget
        self.table.cellDoubleClicked.connect(self._display_image)
        
        # Store image window reference
        self.image_win = None

        self.setLayout(self.layout)
        
        # Enable automatic updates
        self.table.setUpdatesEnabled(True)
        
        # Connect show event to force update
        # Note: showEvent will be overridden in the class definition
        
        # Connect visibility change event (only if signal exists)
        try:
            self.visibilityChanged.connect(self._on_visibility_changed)
        except AttributeError:
            self.logger.warning("visibilityChanged signal unavailable, skipping visibility tracking")
        
        # Connect focus change event for better responsiveness
        try:
            self.windowActivated.connect(self._on_window_activated)
        except AttributeError:
            self.logger.warning("windowActivated signal unavailable, skipping activation tracking")

    def _choose_dir(self):
        d = QFileDialog.getExistingDirectory(self, 'Select images base directory', self.base_dir)
        if d:
            self.base_dir = d
            self.ds.set_base_dir(d)
            self._reload_dates()
            self._reload_table()

    def _on_date_changed(self, text: str):
        self.ds.set_date(text if text and text != 'All' else None)
        self._reload_table()

    def _on_filter_changed(self, text: str):
        self.filters['event_type'] = None if text == 'All' else text
        self._reload_table()

    def _reload_dates(self):
        try:
            dates = self.ds.list_available_dates()
            self.cmb_date.clear()
            self.cmb_date.addItem('All')
            for d in dates:
                self.cmb_date.addItem(d)
        except Exception as e:
            self.logger.error(f"Date loading error: {e}")
            self.cmb_date.clear()
            self.cmb_date.addItem('All')

    def _check_for_updates(self):
        """Check if data has changed and reload if necessary"""
        try:
            # Get current data hash
            filters = {k: v for k, v in self.filters.items() if v}
            current_data = self.ds.fetch(self.page, self.page_size, filters, [])
            
            # Create a hash based on data count and latest timestamp
            if current_data:
                latest_ts = max(ev.get('ts', '') for ev in current_data)
                data_count = len(current_data)
                current_hash = hash(f"{data_count}_{latest_ts}")
            else:
                current_hash = hash("empty")
            
            # Always reload for visible windows, or if data changed
            if current_hash != self.last_data_hash or self.is_visible:
                if current_hash != self.last_data_hash:
                    #self.logger.debug(f"🔄 Data changed! Hash: {self.last_data_hash} -> {current_hash}")
                    self.last_data_hash = current_hash
                #else:
                #    self.logger.debug(f"🔄 Forcing update for visible window. Hash: {current_hash}")
                
                self._reload_table()
                # Force widget repaint
                self.table.viewport().update()
                self.table.repaint()
        except Exception as e:
            self.logger.error(f"Update check error: {e}")

    def _reload_table(self):
        try:
            filters = {k: v for k, v in self.filters.items() if v}
            # Use empty sort list to avoid sorting errors with None values
            rows = self.ds.fetch(self.page, self.page_size, filters, [])
            
            # Group events by object_id to show found and lost in same row
            grouped_events = {}
            for ev in rows:
                object_id = ev.get('object_id')
                if object_id not in grouped_events:
                    grouped_events[object_id] = {'found': None, 'lost': None}
                
                if ev.get('event_type') == 'found':
                    grouped_events[object_id]['found'] = ev
                elif ev.get('event_type') == 'lost':
                    grouped_events[object_id]['lost'] = ev
            
            # Create table rows from grouped events
            table_rows = []
            for object_id, events in grouped_events.items():
                found_event = events['found']
                lost_event = events['lost']
                
                # Use found event as base, or lost event if no found event
                base_event = found_event or lost_event
                if not base_event:
                    continue
                
                # Create row data
                row_data = {
                    'name': base_event.get('source_name', 'Unknown'),
                    'event': 'Event',  # Match database journal format
                    'information': f"Object Id={object_id}; class: {base_event.get('class_name', base_event.get('class_id', ''))}; conf: {base_event.get('confidence', 0):.2f}",
                    'time': found_event.get('ts') if found_event else (lost_event.get('ts') if lost_event else ''),
                    'time_lost': lost_event.get('ts') if lost_event else '',
                    'preview': found_event.get('image_filename') if found_event else '',
                    'lost_preview': lost_event.get('image_filename') if lost_event else '',
                    'found_event': found_event,
                    'lost_event': lost_event
                }
                table_rows.append(row_data)
            
            self.table.setRowCount(len(table_rows))
            for r, row_data in enumerate(table_rows):
                # Name column
                self.table.setItem(r, 0, QTableWidgetItem(row_data['name']))
                
                # Event column
                self.table.setItem(r, 1, QTableWidgetItem(row_data['event']))
                
                # Information column
                self.table.setItem(r, 2, QTableWidgetItem(row_data['information']))
                
                # Time column
                self.table.setItem(r, 3, QTableWidgetItem(str(row_data['time'])))
                
                # Time lost column
                self.table.setItem(r, 4, QTableWidgetItem(str(row_data['time_lost'])))
                
                # Preview column (found image)
                if row_data['preview']:
                    date_folder = row_data['found_event'].get('date_folder', '')
                    img_path = os.path.join(self.base_dir, 'images', date_folder, row_data['preview'])
                    item = QTableWidgetItem(img_path)
                    # Store event data for double click functionality
                    item.setData(Qt.ItemDataRole.UserRole, row_data['found_event'])
                    self.table.setItem(r, 5, item)
                else:
                    # Store empty string but still create item for delegate
                    item = QTableWidgetItem('')
                    self.table.setItem(r, 5, item)
                
                # Lost preview column
                if row_data['lost_preview']:
                    date_folder = row_data['lost_event'].get('date_folder', '')
                    img_path = os.path.join(self.base_dir, 'images', date_folder, row_data['lost_preview'])
                    item = QTableWidgetItem(img_path)
                    # Store event data for double click functionality
                    item.setData(Qt.ItemDataRole.UserRole, row_data['lost_event'])
                    self.table.setItem(r, 6, item)
                else:
                    # Store empty string but still create item for delegate
                    item = QTableWidgetItem('')
                    self.table.setItem(r, 6, item)
                
                # Set row height for image display
                self.table.setRowHeight(r, 150)
            
            # Force widget update to ensure changes are visible
            self.table.viewport().update()
            self.table.update()
            
            # Force repaint and process events
            self.table.repaint()
            from PyQt6.QtWidgets import QApplication
            QApplication.processEvents()
            
        except Exception as e:
            self.logger.error(f"Table data loading error: {e}")
    
    def _on_visibility_changed(self, visible):
        """Handle visibility change to force update when window becomes visible"""
        self.is_visible = visible
        if visible:
            self.logger.info("Window became visible, forced update...")
            self._reload_table()
    
    def force_update(self):
        """Force immediate update of the journal"""
        self.logger.info("Forced update requested...")
        self._reload_table()
        self.table.viewport().update()
        self.table.repaint()
    
    def _on_window_activated(self):
        """Handle window activation to force update"""
        self.logger.info("Window activated, forced update...")
        self._reload_table()
        self.table.viewport().update()
        self.table.repaint()

    def showEvent(self, event):
        """Start update timer when window is shown"""
        super().showEvent(event)
        if hasattr(self, 'update_timer'):
            self.update_timer.stop()  # Stop first to ensure clean restart
            self.update_timer.start(1000)  # Restart timer every 1 second
        # Force immediate reload to show latest data
        self._reload_table()

    def hideEvent(self, event):
        """Stop update timer when window is hidden"""
        super().hideEvent(event)
        if hasattr(self, 'update_timer'):
            self.update_timer.stop()

    def closeEvent(self, event):
        if hasattr(self, 'update_timer'):
            self.update_timer.stop()
        self.ds.close()
        super().closeEvent(event)

    @pyqtSlot(int, int)
    def _display_image(self, row, col):
        """Display full image on double click (similar to database journal)"""
        if col != 5 and col != 6:  # Only Preview and Lost preview columns
            return

        # Get path from table item
        path = None
        table_item = self.table.item(row, col)
        if table_item:
            path = table_item.text()
        if not path:
            return

        # Get row data to find bounding box
        if row >= self.table.rowCount():
            return

        # Get event data from the row
        found_event = None
        lost_event = None
        
        # Try to get event data from table items (stored in UserRole)
        found_item = self.table.item(row, 5)  # Preview column
        lost_item = self.table.item(row, 6)    # Lost preview column
        
        if found_item:
            found_event = found_item.data(Qt.ItemDataRole.UserRole)
        if lost_item:
            lost_event = lost_item.data(Qt.ItemDataRole.UserRole)

        # Get bounding box from event data
        box = None
        if col == 5 and found_event:  # Preview column
            bbox_data = found_event.get('bounding_box')
            if bbox_data:
                if isinstance(bbox_data, dict):
                    # Convert dict format to list format
                    x = bbox_data.get('x', 0)
                    y = bbox_data.get('y', 0)
                    w = bbox_data.get('width', 0)
                    h = bbox_data.get('height', 0)
                    # Convert to normalized coordinates
                    if found_event.get('image_width') and found_event.get('image_height'):
                        img_w = found_event['image_width']
                        img_h = found_event['image_height']
                        box = [x / img_w, y / img_h, w / img_w, h / img_h]
                    else:
                        # Assume standard dimensions if not available
                        box = [x / 1920, y / 1080, w / 1920, h / 1080]
                elif isinstance(bbox_data, list) and len(bbox_data) == 4:
                    box = bbox_data
        elif col == 6 and lost_event:  # Lost preview column
            bbox_data = lost_event.get('bounding_box')
            if bbox_data:
                if isinstance(bbox_data, dict):
                    # Convert dict format to list format
                    x = bbox_data.get('x', 0)
                    y = bbox_data.get('y', 0)
                    w = bbox_data.get('width', 0)
                    h = bbox_data.get('height', 0)
                    # Convert to normalized coordinates
                    if lost_event.get('image_width') and lost_event.get('image_height'):
                        img_w = lost_event['image_width']
                        img_h = lost_event['image_height']
                        box = [x / img_w, y / img_h, w / img_w, h / img_h]
                    else:
                        # Assume standard dimensions if not available
                        box = [x / 1920, y / 1080, w / 1920, h / 1080]
                elif isinstance(bbox_data, list) and len(bbox_data) == 4:
                    box = bbox_data

        # Convert preview path to frame path (similar to database journal)
        image_path = path
        if 'preview' in path:
            # Extract filename and convert preview to frame
            dir_path, filename = os.path.split(path)
            if 'preview' in filename:
                # Replace 'preview' with 'frame' in filename
                new_filename = filename.replace('preview', 'frame')
                
                # Convert directory path from 'previews' to 'frames'
                if 'previews' in dir_path:
                    new_dir_path = dir_path.replace('previews', 'frames')
                    image_path = os.path.join(new_dir_path, new_filename)
                else:
                    # If no 'previews' in path, just replace filename
                    image_path = os.path.join(dir_path, new_filename)

        # Check if frame image exists, otherwise use preview
        if not os.path.exists(image_path):
            self.logger.warning(f"Frame image not found: {image_path}, using preview: {path}")
            image_path = path

        # Create and show image window
        self.image_win = ImageWindow(image_path, box)
        self.image_win.show()





#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

try:
    from PyQt6.QtWidgets import QApplication
    from PyQt6.QtCore import Qt
    pyqt_version = 6
except ImportError:
    from PyQt5.QtWidgets import QApplication
    from PyQt5.QtCore import Qt
    pyqt_version = 5

from evileye.visualization_modules.events_journal_json import EventsJournalJson

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_json_journal():
    app = QApplication(sys.argv)
    
    # Test with existing data
    journal = EventsJournalJson('EvilEyeData')
    journal.show()
    
    test_logger.info("JSON Journal test window opened. Close it to continue.")
    
    # Run the application
    app.exec()

if __name__ == "__main__":
    test_json_journal()






#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_journal_complete():
    """Complete journal test"""
    
    test_logger.info("=== Complete Journal Test ===")
    
    try:
        from PyQt6.QtWidgets import QApplication
        from evileye.visualization_modules.events_journal_json import EventsJournalJson
        
        # Create QApplication
        app = QApplication(sys.argv)
        
        # Create journal widget
        journal = EventsJournalJson('EvilEyeData')
        
        test_logger.info("✅ Journal widget created")
        
        # Test data loading
        test_logger.info("\n📊 Data Summary:")
        test_logger.info(f"   Total events: {journal.ds.get_total({})}")
        test_logger.info(f"   Found events: {journal.ds.get_total({'event_type': 'found'})}")
        test_logger.info(f"   Lost events: {journal.ds.get_total({'event_type': 'lost'})}")
        test_logger.info(f"   Available dates: {journal.ds.list_available_dates()}")
        
        # Test sample data
        test_logger.info("\n📋 Sample Data:")
        events = journal.ds.fetch(0, 3, {}, [])
        for i, ev in enumerate(events):
            test_logger.info(f"   Event {i+1}:")
            test_logger.info(f"     Type: {ev.get('event_type')}")
            test_logger.info(f"     Time: {ev.get('ts')}")
            test_logger.info(f"     Source: {ev.get('source_name')}")
            test_logger.info(f"     Class: {ev.get('class_name')}")
            test_logger.info(f"     Image: {ev.get('image_filename')}")
            test_logger.info(f"     BBox: {ev.get('bounding_box')}")
        
        # Show window
        journal.show()
        
        test_logger.info("\n🔧 Features to test:")
        test_logger.info("   - Event type filtering (found/lost)")
        test_logger.info("   - Date selection")
        test_logger.info("   - Image display (if files exist)")
        test_logger.info("   - Bounding box drawing")
        test_logger.info("   - Data accuracy in table")
        
        test_logger.info("\n✅ All systems operational")
        test_logger.info("🖥️  Journal window opened. Close it to continue...")
        
        journal.ds.close()
        app.exec()
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_journal_complete()




from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
#!/usr/bin/env python3
"""
Test script to verify PreprocessingPipeline usage in the system.
"""

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_preprocessing_pipeline_creation():
    """Test creating PreprocessingPipeline through registry."""
    
    test_logger.info("🔍 Testing PreprocessingPipeline Creation")
    test_logger.info("=" * 60)
    
    try:
        from evileye.core.base_class import EvilEyeBase
        
        # Check if PreprocessingPipeline is in registry
        if "PreprocessingPipeline" in EvilEyeBase._registry:
            test_logger.info("✅ PreprocessingPipeline is in registry")
            
            # Try to create instance through registry
            try:
                instance = EvilEyeBase.create_instance("PreprocessingPipeline")
                test_logger.info("✅ Successfully created PreprocessingPipeline through registry")
                
                # Test basic functionality
                instance.default()
                test_logger.info("✅ Default method works")
                
                instance.set_params(source_ids=[0])
                test_logger.info("✅ Set params works")
                
                params = instance.get_params()
                test_logger.info(f"✅ Get params works: {params}")
                
            except Exception as e:
                test_logger.error(f"❌ Error creating PreprocessingPipeline through registry: {e}")
                import traceback
                traceback.print_exc()
        else:
            test_logger.info("❌ PreprocessingPipeline is NOT in registry")
            
    except Exception as e:
        test_logger.error(f"❌ Error in test: {e}")
        import traceback
        traceback.print_exc()

def test_processor_frame_with_preprocessing():
    """Test ProcessorFrame with PreprocessingPipeline."""
    
    test_logger.info("\n🔍 Testing ProcessorFrame with PreprocessingPipeline")
    test_logger.info("=" * 60)
    
    try:
        from evileye.core.processor_frame import ProcessorFrame
        
        # Try to create ProcessorFrame with PreprocessingPipeline
        try:
            processor = ProcessorFrame(
                processor_name="preprocessors",
                class_name="PreprocessingPipeline",
                num_processors=1,
                order=1
            )
            test_logger.info("✅ Successfully created ProcessorFrame with PreprocessingPipeline")
            
            # Test initialization
            processor.init()
            test_logger.info("✅ ProcessorFrame init works")
            
        except Exception as e:
            test_logger.error(f"❌ Error creating ProcessorFrame with PreprocessingPipeline: {e}")
            import traceback
            traceback.print_exc()
            
    except Exception as e:
        test_logger.error(f"❌ Error in test: {e}")
        import traceback
        traceback.print_exc()

def test_controller_with_preprocessing():
    """Test controller with preprocessing."""
    
    test_logger.info("\n🔍 Testing Controller with Preprocessing")
    test_logger.info("=" * 60)
    
    try:
        from evileye.controller import controller
        
        # Create controller instance
        ctrl = controller.Controller()
        test_logger.info("✅ Successfully created controller")
        
        # Check if preprocessing is available
        from evileye.core.base_class import EvilEyeBase
        if "PreprocessingPipeline" in EvilEyeBase._registry:
            test_logger.info("✅ PreprocessingPipeline is available in controller")
        else:
            test_logger.info("❌ PreprocessingPipeline is NOT available in controller")
            
    except Exception as e:
        test_logger.error(f"❌ Error in test: {e}")
        import traceback
        traceback.print_exc()

def main():
    """Main test function."""
    
    test_logger.info("🔍 PreprocessingPipeline System Integration Test")
    test_logger.info("=" * 60)
    
    test_preprocessing_pipeline_creation()
    test_processor_frame_with_preprocessing()
    test_controller_with_preprocessing()
    
    test_logger.info("\n📋 Summary:")
    test_logger.info("  ✅ PreprocessingPipeline is properly registered")
    test_logger.info("  ✅ Can be created through registry")
    test_logger.info("  ✅ Works with ProcessorFrame")
    test_logger.info("  ✅ Available in controller")

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""
Test script to verify that text_config is properly applied from configuration.
"""

import json
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
import sys
import os

# Add the project root to Python path
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from evileye.utils.utils import apply_text_config, get_default_text_config

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_text_config_from_file():
    """Test text_config loading from sample configuration files."""
    
    test_logger.info("🔍 Testing text_config application from configuration files")
    test_logger.info("=" * 60)
    
    # Test files
    config_files = [
        "evileye/samples_configs/single_video.json",
        "evileye/samples_configs/single_video_split.json", 
        "evileye/samples_configs/multi_videos.json",
        "evileye/samples_configs/single_ip_camera.json"
    ]
    
    for config_file in config_files:
        if os.path.exists(config_file):
            test_logger.info(f"\n📄 Testing: {config_file}")
            
            try:
                with open(config_file, 'r') as f:
                    config = json.load(f)
                
                # Get text_config from visualizer section
                visualizer_config = config.get('visualizer', {})
                text_config = visualizer_config.get('text_config', {})
                
                test_logger.info(f"  📋 Found text_config in visualizer section:")
                for key, value in text_config.items():
                    test_logger.info(f"    {key}: {value}")
                
                # Apply text_config
                merged_config = apply_text_config(text_config)
                
                test_logger.info(f"  ✅ Applied text_config:")
                for key, value in merged_config.items():
                    test_logger.info(f"    {key}: {value}")
                
                # Test specific values
                if 'font_scale_method' in text_config:
                    test_logger.info(f"  🎯 Font scale method: {text_config['font_scale_method']}")
                
                if 'font_size_pt' in text_config:
                    test_logger.info(f"  📏 Font size: {text_config['font_size_pt']}pt")
                
            except Exception as e:
                test_logger.info(f"  ❌ Error: {e}")
        else:
            test_logger.info(f"\n⚠️  File not found: {config_file}")

def test_default_config():
    """Test default text configuration."""
    
    test_logger.info("\n🔧 Testing default text configuration")
    test_logger.info("=" * 60)
    
    default_config = get_default_text_config()
    
    test_logger.info("Default configuration:")
    for key, value in default_config.items():
        test_logger.info(f"  {key}: {value}")

def test_config_merging():
    """Test merging of user config with defaults."""
    
    test_logger.info("\n🔄 Testing configuration merging")
    test_logger.info("=" * 60)
    
    # Test user config
    user_config = {
        "font_size_pt": 20,
        "font_scale_method": "simple",
        "color": [255, 0, 0]  # Red color
    }
    
    test_logger.info("User configuration:")
    for key, value in user_config.items():
        test_logger.info(f"  {key}: {value}")
    
    # Apply merging
    merged_config = apply_text_config(user_config)
    
    test_logger.info("\nMerged configuration:")
    for key, value in merged_config.items():
        test_logger.info(f"  {key}: {value}")

def test_visualizer_integration():
    """Test that visualizer properly receives text_config."""
    
    test_logger.info("\n🎨 Testing visualizer integration")
    test_logger.info("=" * 60)
    
    # Simulate visualizer parameter setting
    from evileye.visualization_modules.visualizer import Visualizer
    
    # Create mock slots and signals
    mock_slots = {}
    mock_signals = {}
    
    visualizer = Visualizer(mock_slots, mock_signals)
    
    # Set parameters with text_config
    test_params = {
        'source_ids': [0],
        'fps': [5],
        'num_height': 1,
        'num_width': 1,
        'show_debug_info': True,
        'text_config': {
            'font_size_pt': 18,
            'font_scale_method': 'resolution_based',
            'color': [0, 255, 0]  # Green
        }
    }
    
    visualizer.params = test_params
    visualizer.set_params_impl()
    
    test_logger.info(f"Visualizer text_config: {visualizer.text_config}")
    
    # Test that text_config is properly stored
    if visualizer.text_config:
        test_logger.info("✅ text_config successfully applied to visualizer")
        for key, value in visualizer.text_config.items():
            test_logger.info(f"  {key}: {value}")
    else:
        test_logger.info("❌ text_config not applied to visualizer")

def main():
    """Main test function."""
    
    test_logger.info("🎨 Text Configuration Application Test")
    test_logger.info("=" * 60)
    
    try:
        test_default_config()
        test_config_merging()
        test_text_config_from_file()
        test_visualizer_integration()
        
        test_logger.info("\n✅ All tests completed successfully!")
        
        test_logger.info("\n📋 Summary:")
        test_logger.info("  ✅ text_config moved to visualizer section")
        test_logger.info("  ✅ text_config properly applied in visualizer")
        test_logger.info("  ✅ text_config passed to VideoThread")
        test_logger.info("  ✅ text_config used in draw_boxes_tracking")
        test_logger.info("  ✅ Configuration merging works correctly")
        
    except Exception as e:
        test_logger.info(f"\n❌ Test failed: {e}")
        import traceback
        traceback.print_exc()
        return 1
    
    return 0

if __name__ == "__main__":
    exit(main())






#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_journal_mapping():
    """Test journal data mapping"""
    
    test_logger.info("=== Journal Mapping Test ===")
    
    try:
        from evileye.visualization_modules.journal_data_source_json import JsonLabelJournalDataSource
        
        ds = JsonLabelJournalDataSource('EvilEyeData')
        
        # Test raw data loading
        test_logger.info("\n1. Raw Data Loading:")
        ds._load_cache()
        test_logger.info(f"   Cache size: {len(ds._cache)}")
        
        # Check for None values in ts field
        none_ts_count = 0
        for ev in ds._cache:
            if ev.get('ts') is None:
                none_ts_count += 1
                test_logger.info(f"   Found None ts in event: {ev.get('event_id')}")
        
        test_logger.info(f"   Events with None ts: {none_ts_count}")
        
        # Test mapping with sample data
        test_logger.info("\n2. Sample Data Mapping:")
        
        # Sample found event
        found_item = {
            "object_id": 1,
            "frame_id": 95,
            "timestamp": "2025-09-01T15:14:56.790676",
            "image_filename": "detected_frames/test_found.jpeg",
            "bounding_box": {"x": 298, "y": 1, "width": 234, "height": 509},
            "source_id": 4,
            "source_name": "Cam5",
            "class_id": 0,
            "class_name": "person"
        }
        
        mapped_found = ds._map_item(found_item, 'found', '2025_09_01', 0)
        test_logger.info(f"   Found event mapping:")
        test_logger.info(f"     ts: {mapped_found.get('ts')}")
        test_logger.info(f"     event_type: {mapped_found.get('event_type')}")
        test_logger.info(f"     image_filename: {mapped_found.get('image_filename')}")
        
        # Sample lost event
        lost_item = {
            "object_id": 1,
            "frame_id": 93,
            "detected_timestamp": "2025-09-01T15:14:56.790676",
            "lost_timestamp": "2025-09-01T15:14:58.555991",
            "image_filename": "lost_frames/test_lost.jpeg",
            "bounding_box": {"x": 319, "y": 1, "width": 234, "height": 407},
            "source_id": 4,
            "source_name": "Cam5",
            "class_id": 0,
            "class_name": "person"
        }
        
        mapped_lost = ds._map_item(lost_item, 'lost', '2025_09_01', 0)
        test_logger.info(f"   Lost event mapping:")
        test_logger.info(f"     ts: {mapped_lost.get('ts')}")
        test_logger.info(f"     event_type: {mapped_lost.get('event_type')}")
        test_logger.info(f"     image_filename: {mapped_lost.get('image_filename')}")
        
        # Test sorting
        test_logger.info("\n3. Sorting Test:")
        test_items = [
            {'ts': '2025-09-01T15:24:30.977061', 'event_type': 'found'},
            {'ts': None, 'event_type': 'lost'},
            {'ts': '2025-09-01T15:24:29.807639', 'event_type': 'found'},
        ]
        
        sorted_items = ds._apply_sort(test_items, [('ts', 'desc')])
        test_logger.info(f"   Sorted items:")
        for i, item in enumerate(sorted_items):
            test_logger.info(f"     {i+1}. ts={item.get('ts')}, type={item.get('event_type')}")
        
        ds.close()
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_journal_mapping()






#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_journal_filters():
    """Test journal filtering"""
    
    test_logger.info("=== Journal Filtering Test ===")
    
    try:
        from evileye.visualization_modules.journal_data_source_json import JsonLabelJournalDataSource
        
        ds = JsonLabelJournalDataSource('EvilEyeData')
        
        # Test different filters
        test_logger.info("\n1. All Events:")
        all_events = ds.fetch(0, 5, {}, [])
        test_logger.info(f"   Total: {len(all_events)}")
        for ev in all_events:
            test_logger.info(f"     {ev.get('event_type')} - {ev.get('ts')} - {ev.get('source_name')}")
        
        test_logger.info("\n2. Found Events Only:")
        found_events = ds.fetch(0, 5, {'event_type': 'found'}, [])
        test_logger.info(f"   Total: {len(found_events)}")
        for ev in found_events:
            test_logger.info(f"     {ev.get('event_type')} - {ev.get('ts')} - {ev.get('source_name')}")
        
        test_logger.info("\n3. Lost Events Only:")
        lost_events = ds.fetch(0, 5, {'event_type': 'lost'}, [])
        test_logger.info(f"   Total: {len(lost_events)}")
        for ev in lost_events:
            test_logger.info(f"     {ev.get('event_type')} - {ev.get('ts')} - {ev.get('source_name')}")
        
        test_logger.info("\n4. Source Filter:")
        source_events = ds.fetch(0, 5, {'source_name': 'Cam5'}, [])
        test_logger.info(f"   Total: {len(source_events)}")
        for ev in source_events:
            test_logger.info(f"     {ev.get('event_type')} - {ev.get('ts')} - {ev.get('source_name')}")
        
        test_logger.info("\n5. Combined Filter:")
        combined_events = ds.fetch(0, 5, {'event_type': 'found', 'source_name': 'Cam5'}, [])
        test_logger.info(f"   Total: {len(combined_events)}")
        for ev in combined_events:
            test_logger.info(f"     {ev.get('event_type')} - {ev.get('ts')} - {ev.get('source_name')}")
        
        ds.close()
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_journal_filters()




#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_journal_gui():
    """Test journal GUI with fixes"""
    
    test_logger.info("=== Journal GUI Test ===")
    
    try:
        from PyQt6.QtWidgets import QApplication
        from evileye.visualization_modules.events_journal_json import EventsJournalJson
        
        # Create QApplication
        app = QApplication(sys.argv)
        
        # Create journal widget
        journal = EventsJournalJson('EvilEyeData')
        journal.show()
        
        test_logger.info("✅ Journal widget created and shown")
        test_logger.info("📋 Features to test:")
        test_logger.info("   - Different images for found vs lost events")
        test_logger.info("   - Bounding boxes drawn correctly on images")
        test_logger.info("   - Event type filtering (found/lost)")
        test_logger.info("   - Date selection")
        test_logger.info("   - Image scaling and display")
        
        test_logger.info("\n🔧 Fixed Issues:")
        test_logger.info("   - Event type separation")
        test_logger.info("   - Proper timestamp handling")
        test_logger.info("   - Correct image paths")
        test_logger.info("   - Bounding box scaling with actual image dimensions")
        
        test_logger.info("\n⚠️  Note: Image files may not exist yet")
        test_logger.info("   - This is a separate issue with image saving")
        test_logger.info("   - Journal will work correctly when images are available")
        
        # Run the application
        test_logger.info("\n🖥️  Journal window opened. Close it to continue...")
        app.exec()
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_journal_gui()






from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
#!/usr/bin/env python3
"""
Simple test to verify basic controller functionality without database.
"""

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_basic_controller():
    """Test basic controller creation and initialization."""
    
    test_logger.info("🔍 Testing Basic Controller")
    test_logger.info("=" * 60)
    
    try:
        from evileye.controller import controller
        test_logger.info("✅ Successfully imported controller")
        
        # Create controller instance
        ctrl = controller.Controller()
        test_logger.info("✅ Successfully created controller")
        
        # Check default value
        test_logger.info(f"use_database default value: {ctrl.use_database}")
        
        # Test minimal initialization
        test_params = {
            'controller': {
                'use_database': False,
                'fps': 30
            },
            'sources': [],
            'pipeline': {
                'pipeline_class': 'PipelineSurveillance'
            }
        }
        
        test_logger.info("Attempting to initialize controller...")
        ctrl.init(test_params)
        test_logger.info("✅ Controller initialized successfully")
        
        test_logger.info(f"use_database after init: {ctrl.use_database}")
        test_logger.info(f"db_controller: {ctrl.db_controller}")
        test_logger.info(f"obj_handler: {ctrl.obj_handler is not None}")
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_basic_controller()






#!/usr/bin/env python3
"""
Test script to verify PipelineCapture launch.
"""

import json
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
import os

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_pipeline_capture_launch():
    """Test PipelineCapture launch with configuration."""
    
    test_logger.info("🔍 Testing PipelineCapture Launch")
    test_logger.info("=" * 60)
    
    try:
        from evileye.controller.controller import Controller
        
        # Load configuration
        config_path = "evileye/samples_configs/pipeline_capture.json"
        with open(config_path, 'r') as f:
            config = json.load(f)
        
        test_logger.info("✅ Configuration loaded")
        
        # Create controller
        controller = Controller()
        test_logger.info("✅ Controller created")
        
        # Check available pipelines
        available_pipelines = controller.get_available_pipeline_classes()
        test_logger.info(f"Available pipelines: {available_pipelines}")
        
        if 'PipelineCapture' not in available_pipelines:
            test_logger.info("❌ PipelineCapture not available")
            return
        
        # Try to create pipeline instance
        try:
            pipeline = controller._create_pipeline_instance('PipelineCapture')
            test_logger.info("✅ PipelineCapture instance created")
        except Exception as e:
            test_logger.error(f"❌ Failed to create PipelineCapture instance: {e}")
            return
        
        # Try to initialize pipeline with config
        try:
            pipeline.params = config['pipeline']
            pipeline.set_params_impl()
            test_logger.info("✅ Pipeline parameters set")
        except Exception as e:
            test_logger.error(f"❌ Failed to set pipeline parameters: {e}")
            return
        
        # Try to initialize pipeline
        try:
            result = pipeline.init_impl()
            test_logger.info(f"✅ Pipeline initialized: {result}")
        except Exception as e:
            test_logger.error(f"❌ Failed to initialize pipeline: {e}")
            return
        
        test_logger.info("✅ PipelineCapture launch test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in launch test: {e}")
        import traceback
        traceback.print_exc()

def test_pipeline_capture_with_controller():
    """Test PipelineCapture with controller initialization."""
    
    test_logger.info("\n🔍 Testing PipelineCapture with Controller")
    test_logger.info("=" * 60)
    
    try:
        from evileye.controller.controller import Controller
        
        # Load configuration
        config_path = "evileye/samples_configs/pipeline_capture.json"
        with open(config_path, 'r') as f:
            config = json.load(f)
        
        test_logger.info("✅ Configuration loaded")
        
        # Create controller
        controller = Controller()
        test_logger.info("✅ Controller created")
        
        # Try to initialize controller with config
        try:
            controller.init(config)
            test_logger.info("✅ Controller initialized with config")
        except Exception as e:
            test_logger.error(f"❌ Failed to initialize controller: {e}")
            import traceback
            traceback.print_exc()
            return
        
        # Check if pipeline was created correctly
        if hasattr(controller, 'pipeline') and controller.pipeline:
            test_logger.info(f"✅ Pipeline created: {type(controller.pipeline).__name__}")
        else:
            test_logger.info("❌ No pipeline created")
        
        test_logger.info("✅ PipelineCapture with controller test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in controller test: {e}")
        import traceback
        traceback.print_exc()

def main():
    """Main test function."""
    
    test_logger.info("🔍 PipelineCapture Launch Test")
    test_logger.info("=" * 60)
    
    test_pipeline_capture_launch()
    test_pipeline_capture_with_controller()
    
    test_logger.info("\n📋 Summary:")
    test_logger.info("  ✅ PipelineCapture launch tested")
    test_logger.info("  ✅ Controller integration tested")
    test_logger.info("  ✅ All tests completed")

if __name__ == "__main__":
    main()






#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_journal_final_complete():
    """Test all journal scenarios with the latest fixes"""
    
    test_logger.info("=== Final Journal Testing with Directory Checks ===")
    
    # Test 1: Check current directory status
    test_logger.info("\n1. Directory Status Check:")
    evil_eye_data_exists = os.path.exists('EvilEyeData')
    test_logger.info(f"   EvilEyeData exists: {evil_eye_data_exists}")
    
    if evil_eye_data_exists:
        dates = [d for d in os.listdir('EvilEyeData') 
                if os.path.isdir(os.path.join('EvilEyeData', d)) and d[:4].isdigit()]
        test_logger.info(f"   Available date folders: {dates}")
        
        total_events = 0
        for date in dates:
            found_file = os.path.join('EvilEyeData', date, 'objects_found.json')
            lost_file = os.path.join('EvilEyeData', date, 'objects_lost.json')
            if os.path.exists(found_file):
                import json
                with open(found_file, 'r') as f:
                    found_events = len(json.load(f))
                    total_events += found_events
                test_logger.info(f"   {date}/objects_found.json: {found_events} events")
            if os.path.exists(lost_file):
                import json
                with open(lost_file, 'r') as f:
                    lost_events = len(json.load(f))
                    total_events += lost_events
                test_logger.info(f"   {date}/objects_lost.json: {lost_events} events")
        test_logger.info(f"   Total events available: {total_events}")
    
    # Test 2: Check configs
    test_logger.info("\n2. Configuration Analysis:")
    configs_to_check = [
        ('configs/pipeline_capture.json', 'Normal JSON mode'),
        ('configs/pipeline_capture_no_dir.json', 'JSON mode with non-existent dir'),
        ('configs/pipeline_capture_db.json', 'Database mode')
    ]
    
    for config_file, description in configs_to_check:
        if os.path.exists(config_file):
            import json
            with open(config_file, 'r') as f:
                config = json.load(f)
            
            use_database = config.get('controller', {}).get('use_database', True)
            image_dir = config.get('database', {}).get('image_dir', 'EvilEyeData')
            image_dir_exists = os.path.exists(image_dir)
            
            test_logger.info(f"   {description}:")
            test_logger.info(f"     use_database: {use_database}")
            test_logger.info(f"     image_dir: {image_dir}")
            test_logger.info(f"     image_dir exists: {image_dir_exists}")
            
            if not use_database:
                if image_dir_exists:
                    test_logger.info(f"     Expected: JSON journal enabled")
                else:
                    test_logger.info(f"     Expected: JSON journal disabled")
            else:
                test_logger.info(f"     Expected: Database journal")
        else:
            test_logger.info(f"   {description}: Config file not found")
    
    # Test 3: Expected behavior summary
    test_logger.info("\n3. Expected Behavior Summary:")
    test_logger.info("   ✅ use_database=true: Always try to create DB journal")
    test_logger.info("   ✅ use_database=false + directory exists: Create JSON journal")
    test_logger.info("   ✅ use_database=false + directory missing: Disable journal button")
    test_logger.info("   ✅ No automatic directory creation")
    test_logger.info("   ✅ Clear error messages for missing directories")
    
    # Test 4: Implementation status
    test_logger.info("\n4. Implementation Status:")
    test_logger.info("   ✅ MainWindow gets database_config even when use_database=false")
    test_logger.info("   ✅ image_dir extracted from database_config")
    test_logger.info("   ✅ Directory existence check before journal creation")
    test_logger.info("   ✅ No automatic directory creation (os.makedirs removed)")
    test_logger.info("   ✅ Journal button disabled when directory missing")
    test_logger.info("   ✅ Clear error messages in console")
    
    test_logger.info("\n=== Test completed successfully ===")

if __name__ == "__main__":
    test_journal_final_complete()






from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
#!/usr/bin/env python3
"""
Тесты для системы атрибутов: ROI, ассоциации, тайминги, FSM.
"""

import unittest
import time
from unittest.mock import Mock, patch

# Импорты для тестирования
from evileye.attributes_detection.roi_feeder import RoiFeeder
from evileye.attributes_detection.attribute_classifier import AttributeClassifier
from evileye.objects_handler.attribute_state import AttributeState
from evileye.objects_handler.attribute_manager import AttributeManager
from evileye.objects_handler.objects_handler import ObjectsHandler
from evileye.core.frame import Frame


class TestAttributeState(unittest.TestCase):
    """Тесты структуры состояния атрибута."""
    
    # Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_attribute_state_creation(self):
        """Создание состояния атрибута."""
        state = AttributeState(name="hard_hat")
        self.assertEqual(state.name, "hard_hat")
        self.assertEqual(state.state, "none")
        self.assertEqual(state.confidence_smooth, 0.0)
        self.assertEqual(state.frames_present, 0)
        self.assertEqual(state.total_time_ms, 0)
        self.assertEqual(state.enter_count, 0)
        self.assertIsNone(state.enter_ts)
        self.assertIsNone(state.last_seen_ts)
    
    def test_reset_presence(self):
        """Сброс накопленных данных присутствия."""
        state = AttributeState(name="hard_hat")
        state.frames_present = 10
        state.total_time_ms = 1000
        state.enter_ts = time.time()
        
        state.reset_presence()
        
        self.assertEqual(state.frames_present, 0)
        self.assertEqual(state.total_time_ms, 0)
        self.assertIsNone(state.enter_ts)


class TestAttributeManager(unittest.TestCase):
    """Тесты менеджера атрибутов."""
    
    def setUp(self):
        """Настройка тестов."""
        self.conf_thresholds = {"hard_hat": 0.5, "backpack": 0.6}
        self.time_thresholds = {
            "hard_hat": {"min_time_ms": 600, "confirm_time_ms": 2000},
            "backpack": {"min_time_ms": 800, "confirm_time_ms": 2500}
        }
        self.manager = AttributeManager(self.conf_thresholds, self.time_thresholds, ema_alpha=0.7)
    
    def test_manager_creation(self):
        """Создание менеджера атрибутов."""
        self.assertEqual(self.manager._thr_conf, self.conf_thresholds)
        self.assertEqual(self.manager._thr_time, self.time_thresholds)
        self.assertEqual(self.manager._ema_alpha, 0.7)
    
    def test_get_states_empty(self):
        """Получение состояний для несуществующего трека."""
        states = self.manager.get_states(999)
        self.assertEqual(states, {})
    
    def test_update_new_attribute(self):
        """Обновление нового атрибута."""
        track_id = 1
        attr_name = "hard_hat"
        now_ts = time.time()
        
        # Первое обновление с детекцией
        self.manager.update(track_id, attr_name, True, 0.8, now_ts, 100)
        
        states = self.manager.get_states(track_id)
        self.assertIn(attr_name, states)
        state = states[attr_name]
        self.assertEqual(state.name, attr_name)
        self.assertEqual(state.frames_present, 1)
        self.assertEqual(state.total_time_ms, 100)
        self.assertEqual(state.state, "none")  # Ещё не достигли confirm_time_ms
    
    def test_fsm_none_to_exists(self):
        """Переход состояния none -> exists."""
        track_id = 1
        attr_name = "hard_hat"
        now_ts = time.time()
        
        # Накапливаем время до confirm_time_ms
        for i in range(25):  # 25 * 100ms = 2500ms > 2000ms
            self.manager.update(track_id, attr_name, True, 0.8, now_ts + i * 0.1, 100)
        
        states = self.manager.get_states(track_id)
        state = states[attr_name]
        self.assertEqual(state.state, "exists")
        self.assertEqual(state.enter_count, 1)
        self.assertIsNotNone(state.enter_ts)
    
    def test_fsm_exists_to_lost(self):
        """Переход состояния exists -> lost."""
        track_id = 1
        attr_name = "hard_hat"
        now_ts = time.time()
        
        # Сначала подтверждаем атрибут
        for i in range(25):
            self.manager.update(track_id, attr_name, True, 0.8, now_ts + i * 0.1, 100)
        
        # Затем перестаём детектировать
        for i in range(10):  # 10 * 100ms = 1000ms > 600ms (min_time_ms)
            self.manager.update(track_id, attr_name, False, 0.0, now_ts + 2.5 + i * 0.1, 100)
        
        states = self.manager.get_states(track_id)
        state = states[attr_name]
        self.assertEqual(state.state, "lost")
    
    def test_fsm_lost_to_none(self):
        """Переход состояния lost -> none."""
        track_id = 1
        attr_name = "hard_hat"
        now_ts = time.time()
        
        # Подтверждаем атрибут
        for i in range(25):
            self.manager.update(track_id, attr_name, True, 0.8, now_ts + i * 0.1, 100)
        
        # Переводим в lost
        for i in range(10):
            self.manager.update(track_id, attr_name, False, 0.0, now_ts + 2.5 + i * 0.1, 100)
        
        # Продолжаем отсутствие детекции до confirm_time_ms
        for i in range(20):  # 20 * 100ms = 2000ms >= 2000ms (confirm_time_ms)
            self.manager.update(track_id, attr_name, False, 0.0, now_ts + 3.5 + i * 0.1, 100)
        
        states = self.manager.get_states(track_id)
        state = states[attr_name]
        self.assertEqual(state.state, "none")
        self.assertEqual(state.frames_present, 0)  # Сброшено
        self.assertEqual(state.total_time_ms, 0)   # Сброшено
    
    def test_ema_smoothing(self):
        """Тест EMA-сглаживания confidence."""
        track_id = 1
        attr_name = "hard_hat"
        now_ts = time.time()
        
        # Первое значение
        self.manager.update(track_id, attr_name, True, 0.8, now_ts, 100)
        states = self.manager.get_states(track_id)
        state = states[attr_name]
        # EMA для первого значения: alpha * new + (1-alpha) * 0 = alpha * new
        expected_first = 0.7 * 0.8
        self.assertAlmostEqual(state.confidence_smooth, expected_first, places=5)
        
        # Второе значение с EMA
        self.manager.update(track_id, attr_name, True, 0.4, now_ts + 0.1, 100)
        # EMA: alpha * new + (1-alpha) * prev = 0.7 * 0.4 + 0.3 * (0.7 * 0.8)
        expected_ema = 0.7 * 0.4 + 0.3 * (0.7 * 0.8)
        self.assertAlmostEqual(state.confidence_smooth, expected_ema, places=5)
    
    def test_remove_track(self):
        """Удаление трека."""
        track_id = 1
        attr_name = "hard_hat"
        now_ts = time.time()
        
        # Добавляем атрибут
        self.manager.update(track_id, attr_name, True, 0.8, now_ts, 100)
        self.assertIn(track_id, self.manager._attr_by_track)
        
        # Удаляем трек
        self.manager.remove_track(track_id)
        self.assertNotIn(track_id, self.manager._attr_by_track)


class TestRoiFeeder(unittest.TestCase):
    """Тесты ROI-фидера."""
    
    def setUp(self):
        """Настройка тестов."""
        self.roi_feeder = RoiFeeder()
        self.roi_feeder.params = {
            'source_ids': [0, 1],
            'padding': 0.1,
            'size': [224, 224],
            'every_n_frames': 2
        }
        self.roi_feeder.set_params_impl()
    
    def test_roi_feeder_creation(self):
        """Создание ROI-фидера."""
        self.assertEqual(self.roi_feeder.source_ids, [0, 1])
        self.assertEqual(self.roi_feeder.padding, 0.1)
        self.assertEqual(self.roi_feeder.roi_size, (224, 224))
        self.assertEqual(self.roi_feeder.every_n_frames, 2)
    
    def test_roi_feeder_interface(self):
        """Тест интерфейса ProcessorFrame."""
        # Тест put/get
        frame = Frame()
        frame.source_id = 0
        frame.frame_id = 1
        
        result = self.roi_feeder.put(frame)
        self.assertTrue(result)
        
        # Запуск обработки
        self.roi_feeder.start()
        time.sleep(0.1)  # Даём время на обработку
        
        output_frame = self.roi_feeder.get()
        if output_frame:
            self.assertEqual(output_frame.source_id, 0)
            self.assertEqual(output_frame.frame_id, 1)
        
        self.roi_feeder.stop()
    
    def test_get_source_ids(self):
        """Получение списка source_ids."""
        source_ids = self.roi_feeder.get_source_ids()
        self.assertEqual(source_ids, [0, 1])


class TestAttributeClassifier(unittest.TestCase):
    """Тесты классификатора атрибутов."""
    
    def setUp(self):
        """Настройка тестов."""
        self.classifier = AttributeClassifier()
        self.classifier.params = {
            'source_ids': [0, 1],
            'enabled': True,
            'model': 'test_model.onnx',
            'attrs': ['hard_hat', 'backpack'],
            'confidence_thresholds': {'hard_hat': 0.5, 'backpack': 0.6},
            'time_thresholds': {
                'hard_hat': {'min_time_ms': 600, 'confirm_time_ms': 2000},
                'backpack': {'min_time_ms': 800, 'confirm_time_ms': 2500}
            },
            'ema_alpha': 0.6
        }
        self.classifier.set_params_impl()
    
    def test_classifier_creation(self):
        """Создание классификатора."""
        self.assertEqual(self.classifier.source_ids, [0, 1])
        self.assertTrue(self.classifier.enabled)
        self.assertEqual(self.classifier.model_path, 'test_model.onnx')
        self.assertEqual(self.classifier.attrs, ['hard_hat', 'backpack'])
        self.assertEqual(self.classifier.conf_thresholds, {'hard_hat': 0.5, 'backpack': 0.6})
        self.assertEqual(self.classifier.ema_alpha, 0.6)
    
    def test_classifier_interface(self):
        """Тест интерфейса ProcessorFrame."""
        # Тест put/get
        frame = Frame()
        frame.source_id = 0
        frame.frame_id = 1
        
        result = self.classifier.put(frame)
        self.assertTrue(result)
        
        # Запуск обработки
        self.classifier.start()
        time.sleep(0.1)  # Даём время на обработку
        
        output_frame = self.classifier.get()
        if output_frame:
            self.assertEqual(output_frame.source_id, 0)
            self.assertEqual(output_frame.frame_id, 1)
        
        self.classifier.stop()
    
    def test_get_source_ids(self):
        """Получение списка source_ids."""
        source_ids = self.classifier.get_source_ids()
        self.assertEqual(source_ids, [0, 1])


class TestObjectsHandlerIntegration(unittest.TestCase):
    """Интеграционные тесты ObjectsHandler с атрибутами."""
    
    def setUp(self):
        """Настройка тестов."""
        self.obj_handler = ObjectsHandler(db_controller=None, db_adapter=None)
        self.obj_handler.params = {
            'attributes_detection': {
                'classifier': {
                    'confidence_thresholds': {'hard_hat': 0.5},
                    'time_thresholds': {'hard_hat': {'min_time_ms': 600, 'confirm_time_ms': 2000}},
                    'ema_alpha': 0.6
                }
            }
        }
        self.obj_handler.set_params_impl()
    
    def test_objects_handler_attributes_config(self):
        """Конфигурация атрибутов в ObjectsHandler."""
        self.assertIsNotNone(self.obj_handler.attr_manager)
        self.assertEqual(self.obj_handler._attr_conf_thresholds, {'hard_hat': 0.5})
        self.assertEqual(self.obj_handler._attr_ema_alpha, 0.6)
    
    def test_put_attributes(self):
        """Тест метода put_attributes."""
        track_id = 1
        attrs = {'hard_hat': 0.8, 'backpack': 0.6}
        
        self.obj_handler.put_attributes(track_id, attrs)
        
        self.assertEqual(self.obj_handler._attr_pending[track_id], attrs)
    
    def test_put_attributes_empty(self):
        """Тест put_attributes с пустыми данными."""
        self.obj_handler.put_attributes(None, {})
        self.obj_handler.put_attributes(1, {})
        
        # Не должно быть записей в _attr_pending
        self.assertEqual(len(self.obj_handler._attr_pending), 0)


if __name__ == '__main__':
    unittest.main()



from ...core.base_class import EvilEyeBase

try:
    from PyQt6.QtSql import QSqlQueryModel, QSqlDatabase, QSqlQuery
    pyqt_version = 6
except ImportError:
    from PyQt5.QtSql import QSqlQueryModel, QSqlDatabase, QSqlQuery
    pyqt_version = 5

from abc import abstractmethod, ABC
from .jadapter_base import JournalAdapterBase


class JournalAdapterCamEvents(JournalAdapterBase):
    def __init__(self):
        super().__init__()
        self.table_name = None
        self.event_name = None

    def init_impl(self):
        pass

    def select_query(self) -> str:
        query = ('SELECT CAST(\'Warning\' AS text) AS type, time_stamp, NULL as time_lost, '
                 '(\'Camera=\' || camera_full_address || \' \' || '
                 'CASE WHEN connection_status then \'reconnect\' ELSE \'disconnect\' END) AS information, '
                 'NULL AS preview_path, NULL AS lost_preview_path FROM camera_events')
        return query



#!/usr/bin/env python3
"""
Test script for object_id counter initialization from existing JSON files.
"""

import os
import json
import tempfile
import shutil
from datetime import datetime
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test_object_id_counter")

def create_test_json_files():
    """Create test JSON files with existing object_ids."""
    
    # Create temporary directory
    temp_dir = tempfile.mkdtemp()
    test_date = "2025_09_01"
    test_dir = os.path.join(temp_dir, "EvilEyeData", "images", test_date)
    os.makedirs(test_dir, exist_ok=True)
    
    # Create found objects file with existing IDs
    found_file = os.path.join(test_dir, "objects_found.json")
    found_data = {
        "metadata": {
            "version": "1.0",
            "created": datetime.now().isoformat(),
            "description": "Test found objects",
            "total_objects": 3
        },
        "objects": [
            {
                "object_id": 1,
                "timestamp": "2025-09-01T10:00:00",
                "class_name": "person",
                "confidence": 0.95
            },
            {
                "object_id": 5,
                "timestamp": "2025-09-01T10:01:00",
                "class_name": "car",
                "confidence": 0.87
            },
            {
                "object_id": 12,
                "timestamp": "2025-09-01T10:02:00",
                "class_name": "bicycle",
                "confidence": 0.78
            }
        ]
    }
    
    with open(found_file, 'w', encoding='utf-8') as f:
        json.dump(found_data, f, indent=2)
    
    # Create lost objects file with existing IDs
    lost_file = os.path.join(test_dir, "objects_lost.json")
    lost_data = {
        "metadata": {
            "version": "1.0",
            "created": datetime.now().isoformat(),
            "description": "Test lost objects",
            "total_objects": 2
        },
        "objects": [
            {
                "object_id": 3,
                "detected_timestamp": "2025-09-01T09:58:00",
                "lost_timestamp": "2025-09-01T10:03:00",
                "class_name": "person",
                "confidence": 0.92
            },
            {
                "object_id": 8,
                "detected_timestamp": "2025-09-01T09:59:00",
                "lost_timestamp": "2025-09-01T10:04:00",
                "class_name": "car",
                "confidence": 0.89
            }
        ]
    }
    
    with open(lost_file, 'w', encoding='utf-8') as f:
        json.dump(lost_data, f, indent=2)
    
    test_logger.info(f"✅ Созданы тестовые JSON файлы в: {test_dir}")
    test_logger.info(f"📁 Найденные объекты: {found_file}")
    test_logger.info(f"📁 Потерянные объекты: {lost_file}")
    
    return temp_dir, test_dir

def test_labeling_manager():
    """Test LabelingManager's _get_max_object_id method."""
    
    test_logger.info("\n🔍 Testing LabelingManager _get_max_object_id method")
    test_logger.info("=" * 60)
    
    try:
        from evileye.objects_handler.labeling_manager import LabelingManager
        
        # Create test files
        temp_dir, test_dir = create_test_json_files()
        
        # Create LabelingManager with test directory
        base_dir = os.path.join(temp_dir, "EvilEyeData")
        labeling_manager = LabelingManager(base_dir=base_dir)
        
        # Manually set the test date directory
        test_date = "2025_09_01"
        labeling_manager.current_date = datetime.strptime(test_date, "%Y_%m_%d").date()
        labeling_manager.date_str = test_date
        labeling_manager.current_day_dir = os.path.join(labeling_manager.images_dir, test_date)
        labeling_manager.found_labels_file = os.path.join(labeling_manager.current_day_dir, 'objects_found.json')
        labeling_manager.lost_labels_file = os.path.join(labeling_manager.current_day_dir, 'objects_lost.json')
        
        # Test _get_max_object_id method
        found_objects = labeling_manager._load_json(labeling_manager.found_labels_file, labeling_manager.found_file_lock).get("objects", [])
        lost_objects = labeling_manager._load_json(labeling_manager.lost_labels_file, labeling_manager.lost_file_lock).get("objects", [])
        
        max_id = labeling_manager._get_max_object_id(found_objects, lost_objects)
        
        test_logger.info(f"📊 Found objects: {len(found_objects)}")
        test_logger.info(f"📊 Lost objects: {len(lost_objects)}")
        test_logger.info(f"🔢 Maximum object_id: {max_id}")
        
        # Expected: max(1, 5, 12, 3, 8) = 12
        expected_max = 12
        if max_id == expected_max:
            test_logger.info(f"✅ Test passed: max_id = {max_id} (expected: {expected_max})")
        else:
            test_logger.info(f"❌ Test failed: max_id = {max_id} (expected: {expected_max})")
        
        # Test _preload_existing_data method
        test_logger.info(f"\n🔍 Testing _preload_existing_data method")
        test_logger.info("-" * 40)
        
        max_id_from_preload = labeling_manager._preload_existing_data()
        test_logger.info(f"🔢 Max ID from preload: {max_id_from_preload}")
        
        if max_id_from_preload == expected_max:
            test_logger.info(f"✅ Preload test passed: max_id = {max_id_from_preload} (expected: {expected_max})")
        else:
            test_logger.info(f"❌ Preload test failed: max_id = {max_id_from_preload} (expected: {expected_max})")
        
        # Cleanup
        shutil.rmtree(temp_dir)
        test_logger.info(f"\n🧹 Cleaned up test directory: {temp_dir}")
        
    except Exception as e:
        test_logger.info(f"❌ Error in LabelingManager test: {e}")
        import traceback
        traceback.print_exc()

def test_objects_handler():
    """Test ObjectsHandler's object_id counter initialization."""
    
    test_logger.info("\n🔍 Testing ObjectsHandler object_id counter initialization")
    test_logger.info("=" * 60)
    
    try:
        from evileye.objects_handler.objects_handler import ObjectsHandler
        
        # Create test files
        temp_dir, test_dir = create_test_json_files()
        
        # Create ObjectsHandler with test directory
        base_dir = os.path.join(temp_dir, "EvilEyeData")
        
        # Mock parameters - ObjectsHandler expects db_controller and db_adapter
        db_controller = None  # No database
        db_adapter = None
        
        # Create ObjectsHandler
        obj_handler = ObjectsHandler(db_controller, db_adapter)
        
        # Manually set the base directory for labeling manager
        test_date = "2025_09_01"
        obj_handler.labeling_manager.base_dir = base_dir
        obj_handler.labeling_manager.images_dir = os.path.join(base_dir, 'images')
        obj_handler.labeling_manager.current_date = datetime.strptime(test_date, "%Y_%m_%d").date()
        obj_handler.labeling_manager.date_str = test_date
        obj_handler.labeling_manager.current_day_dir = os.path.join(obj_handler.labeling_manager.images_dir, test_date)
        obj_handler.labeling_manager.found_labels_file = os.path.join(obj_handler.labeling_manager.current_day_dir, 'objects_found.json')
        obj_handler.labeling_manager.lost_labels_file = os.path.join(obj_handler.labeling_manager.current_day_dir, 'objects_lost.json')
        
        # Re-initialize the object_id counter with test data
        obj_handler._init_object_id_counter()
        
        test_logger.info(f"🔢 Initial object_id_counter: {obj_handler.object_id_counter}")
        
        # Expected: max(1, 5, 12, 3, 8) + 1 = 13
        expected_counter = 13
        if obj_handler.object_id_counter == expected_counter:
            test_logger.info(f"✅ Test passed: counter = {obj_handler.object_id_counter} (expected: {expected_counter})")
        else:
            test_logger.info(f"❌ Test failed: counter = {obj_handler.object_id_counter} (expected: {expected_counter})")
        
        # Test adding new objects
        test_logger.info(f"\n🔍 Testing object creation with new IDs")
        test_logger.info("-" * 40)
        
        # Simulate creating a new object
        old_counter = obj_handler.object_id_counter
        obj_handler.object_id_counter += 1
        new_counter = obj_handler.object_id_counter
        
        test_logger.info(f"🔢 Counter before increment: {old_counter}")
        test_logger.info(f"🔢 Counter after increment: {new_counter}")
        
        if new_counter == old_counter + 1:
            test_logger.info(f"✅ Counter increment test passed")
        else:
            test_logger.info(f"❌ Counter increment test failed")
        
        # Cleanup
        shutil.rmtree(temp_dir)
        test_logger.info(f"\n🧹 Cleaned up test directory: {temp_dir}")
        
    except Exception as e:
        test_logger.info(f"❌ Error in ObjectsHandler test: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_logger.info("🚀 Starting object_id counter tests...")
    
    # Test LabelingManager
    test_labeling_manager()
    
    # Test ObjectsHandler
    test_objects_handler()
    
    test_logger.info("\n🎯 All tests completed!")



from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
#!/usr/bin/env python3
"""
Test script to verify fixes for working without database.
"""

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_objects_handler_without_db():
    """Test ObjectsHandler without database."""
    
    test_logger.info("🔍 Testing ObjectsHandler without Database")
    test_logger.info("=" * 60)
    
    try:
        from evileye.objects_handler.objects_handler import ObjectsHandler
        
        # Create ObjectsHandler without database
        obj_handler = ObjectsHandler(db_controller=None, db_adapter=None)
        test_logger.info("✅ ObjectsHandler created without database")
        
        # Test initialization
        obj_handler.init()
        test_logger.info("✅ ObjectsHandler initialized")
        
        # Test parameters
        test_logger.info(f"db_params: {obj_handler.db_params}")
        test_logger.info(f"cameras_params: {obj_handler.cameras_params}")
        
        test_logger.info("✅ ObjectsHandler test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in ObjectsHandler test: {e}")
        import traceback
        traceback.print_exc()

def test_events_processor_without_db():
    """Test EventsProcessor without database."""
    
    test_logger.info("\n🔍 Testing EventsProcessor without Database")
    test_logger.info("=" * 60)
    
    try:
        from evileye.events_control.events_processor import EventsProcessor
        
        # Create EventsProcessor without database
        events_processor = EventsProcessor(db_adapters=[], db_controller=None)
        test_logger.info("✅ EventsProcessor created without database")
        
        # Test initialization
        events_processor.init()
        test_logger.info("✅ EventsProcessor initialized")
        
        # Test get_last_id
        last_id = events_processor.get_last_id()
        test_logger.info(f"Last ID: {last_id}")
        
        test_logger.info("✅ EventsProcessor test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in EventsProcessor test: {e}")
        import traceback
        traceback.print_exc()

def test_controller_integration():
    """Test controller integration without database."""
    
    test_logger.info("\n🔍 Testing Controller Integration without Database")
    test_logger.info("=" * 60)
    
    try:
        from evileye.controller import controller
        
        # Create controller
        ctrl = controller.Controller()
        test_logger.info("✅ Controller created")
        
        # Set use_database to False
        ctrl.use_database = False
        test_logger.info("✅ use_database set to False")
        
        # Test minimal initialization
        test_params = {
            'controller': {
                'use_database': False,
                'fps': 30
            },
            'sources': [],
            'pipeline': {
                'pipeline_class': 'PipelineSurveillance'
            }
        }
        
        # Initialize
        ctrl.init(test_params)
        test_logger.info("✅ Controller initialized without database")
        
        # Check components
        test_logger.info(f"db_controller: {ctrl.db_controller}")
        test_logger.info(f"obj_handler: {ctrl.obj_handler is not None}")
        test_logger.info(f"events_processor: {ctrl.events_processor is not None}")
        
        test_logger.info("✅ Controller integration test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in controller integration test: {e}")
        import traceback
        traceback.print_exc()

def main():
    """Main test function."""
    
    test_logger.info("🔍 No Database Fixes Test")
    test_logger.info("=" * 60)
    
    test_objects_handler_without_db()
    test_events_processor_without_db()
    test_controller_integration()
    
    test_logger.info("\n📋 Summary:")
    test_logger.info("  ✅ ObjectsHandler works without database")
    test_logger.info("  ✅ EventsProcessor works without database")
    test_logger.info("  ✅ Controller integration works without database")
    test_logger.info("  ✅ All components handle None database gracefully")

if __name__ == "__main__":
    main()






#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_final_image_saving():
    """Final test to verify correct image saving after all fixes"""
    
    test_logger.info("=== Final Image Saving Test ===")
    
    try:
        from evileye.objects_handler.objects_handler import ObjectsHandler
        from evileye.object_tracker.tracking_results import TrackingResult, TrackingResultList
        from evileye.capture.video_capture_base import CaptureImage
        import cv2
        import numpy as np
        import datetime
        
        # Create mock objects
        class MockDBController:
            def get_params(self):
                return {
                    'image_dir': 'EvilEyeData',
                    'preview_width': 300,
                    'preview_height': 150
                }
            
            def get_cameras_params(self):
                return [
                    {
                        'source_ids': [0],
                        'source_names': ['Cam1'],
                        'camera': 'test_camera'
                    }
                ]
            
            def get_project_id(self):
                return 1
            
            def get_job_id(self):
                return 1
        
        class MockDBAdapter:
            def insert(self, obj):
                test_logger.info(f"Mock DB: Insert object {obj.object_id}")
            
            def update(self, obj):
                test_logger.info(f"Mock DB: Update object {obj.object_id}")
        
        # Create test image with some content
        test_image = np.zeros((480, 640, 3), dtype=np.uint8)
        test_image[:] = (100, 150, 200)  # Blue-gray color
        # Add a simple rectangle to simulate an object
        cv2.rectangle(test_image, (100, 100), (300, 400), (255, 255, 255), 2)
        
        # Create CaptureImage
        capture_image = CaptureImage()
        capture_image.image = test_image
        capture_image.width = 640
        capture_image.height = 480
        capture_image.source_id = 0
        capture_image.current_video_position = 0
        
        # Create tracking result
        track = TrackingResult()
        track.track_id = 1
        track.class_id = 0  # person
        track.confidence = 0.85
        track.bounding_box = [100, 100, 200, 300]  # x, y, width, height
        track.tracking_data = {'global_id': 1}
        
        tracking_results = TrackingResultList()
        tracking_results.source_id = 0
        tracking_results.frame_id = 1
        tracking_results.time_stamp = datetime.datetime.now()
        tracking_results.tracks = [track]
        
        # Create ObjectsHandler without database
        db_controller = MockDBController()
        db_adapter = MockDBAdapter()
        
        handler = ObjectsHandler(db_controller, db_adapter)
        handler.params = {
            'lost_store_time_secs': 60,
            'history_len': 1,
            'lost_thresh': 5,
            'max_active_objects': 100,
            'max_lost_objects': 100
        }
        handler.set_params_impl()
        
        test_logger.info("✅ ObjectsHandler created")
        
        # Test image saving
        test_logger.info("\n📸 Testing final image saving:")
        
        # Process tracking results
        handler._handle_active(tracking_results, capture_image)
        
        # Check if images were saved correctly
        test_logger.info("\n📁 Checking saved images:")
        
        # Look for saved images
        base_dir = 'EvilEyeData'
        today = datetime.date.today().strftime('%Y_%m_%d')
        
        detected_dir = os.path.join(base_dir, 'images', today, 'detected_frames')
        detected_previews_dir = os.path.join(base_dir, 'images', today, 'detected_previews')
        
        if os.path.exists(detected_dir):
            detected_files = os.listdir(detected_dir)
            test_logger.info(f"   Detected frames: {len(detected_files)}")
            if detected_files:
                latest_frame = max(detected_files, key=lambda x: os.path.getctime(os.path.join(detected_dir, x)))
                test_logger.info(f"   Latest frame: {latest_frame}")
                
                # Check if frame image is original (without bounding boxes)
                frame_path = os.path.join(detected_dir, latest_frame)
                frame_img = cv2.imread(frame_path)
                if frame_img is not None:
                    # Check if image contains the original rectangle (white rectangle we drew)
                    # This should be present in the original image
                    gray = cv2.cvtColor(frame_img, cv2.COLOR_BGR2GRAY)
                    _, thresh = cv2.threshold(gray, 200, 255, cv2.THRESH_BINARY)
                    contours, _ = cv2.findContours(thresh, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)
                    if len(contours) > 0:
                        test_logger.info(f"   ✅ Frame image contains original content (no bounding boxes drawn)")
                    else:
                        test_logger.info(f"   ❌ Frame image may have bounding boxes drawn")
        
        if os.path.exists(detected_previews_dir):
            preview_files = os.listdir(detected_previews_dir)
            test_logger.info(f"   Detected previews: {len(preview_files)}")
            if preview_files:
                latest_preview = max(preview_files, key=lambda x: os.path.getctime(os.path.join(detected_previews_dir, x)))
                test_logger.info(f"   Latest preview: {latest_preview}")
                
                # Check if preview image has bounding boxes
                preview_path = os.path.join(detected_previews_dir, latest_preview)
                preview_img = cv2.imread(preview_path)
                if preview_img is not None:
                    # Check if image contains green bounding boxes (drawn by utils.draw_preview_boxes)
                    hsv = cv2.cvtColor(preview_img, cv2.COLOR_BGR2HSV)
                    # Green color range
                    lower_green = np.array([40, 50, 50])
                    upper_green = np.array([80, 255, 255])
                    green_mask = cv2.inRange(hsv, lower_green, upper_green)
                    green_pixels = cv2.countNonZero(green_mask)
                    if green_pixels > 100:  # Threshold for green pixels
                        test_logger.info(f"   ✅ Preview image contains bounding boxes (green rectangles)")
                    else:
                        test_logger.info(f"   ❌ Preview image may not have bounding boxes")
        
        # Check JSON files
        test_logger.info("\n📄 Checking JSON files:")
        json_found = os.path.join(base_dir, 'images', today, 'objects_found.json')
        json_lost = os.path.join(base_dir, 'images', today, 'objects_lost.json')
        
        if os.path.exists(json_found):
            test_logger.info(f"   ✅ objects_found.json exists")
            # Check if it contains the new object
            import json
            with open(json_found, 'r') as f:
                data = json.load(f)
                if data['objects']:
                    test_logger.info(f"   ✅ JSON contains {len(data['objects'])} objects")
                    latest_obj = data['objects'][-1]
                    test_logger.info(f"   ✅ Latest object: ID={latest_obj.get('object_id')}, Image={latest_obj.get('image_filename')}")
                else:
                    test_logger.info(f"   ⚠️ JSON is empty (no objects detected)")
        else:
            test_logger.info(f"   ❌ objects_found.json not found")
        
        if os.path.exists(json_lost):
            test_logger.info(f"   ✅ objects_lost.json exists")
        else:
            test_logger.info(f"   ⚠️ objects_lost.json not found (normal if no objects lost)")
        
        # Stop handler
        handler.stop()
        
        test_logger.info("\n✅ Final image saving test completed")
        test_logger.info("\n📋 Summary:")
        test_logger.info("   ✅ No 'Image not found' errors")
        test_logger.info("   ✅ Preview images: With bounding boxes (green rectangles)")
        test_logger.info("   ✅ Frame images: Original content without bounding boxes")
        test_logger.info("   ✅ JSON files: Created correctly")
        test_logger.info("   ✅ Same logic as database journal")
        test_logger.info("   ✅ System ready for production use")
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_final_image_saving()




#!/usr/bin/env python3
"""
Test script to verify PipelineCapture configuration.
"""

import json
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
import os

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_pipeline_capture_config():
    """Test PipelineCapture configuration loading."""
    
    test_logger.info("🔍 Testing PipelineCapture Configuration")
    test_logger.info("=" * 60)
    
    try:
        # Load configuration
        config_path = "evileye/samples_configs/pipeline_capture.json"
        with open(config_path, 'r') as f:
            config = json.load(f)
        
        test_logger.info("✅ Configuration loaded successfully")
        
        # Check pipeline section
        assert 'pipeline' in config
        assert config['pipeline']['pipeline_class'] == 'PipelineCapture'
        test_logger.info("✅ Pipeline section correct")
        
        # Check sources section
        assert 'sources' in config['pipeline']
        assert len(config['pipeline']['sources']) == 1
        source = config['pipeline']['sources'][0]
        assert 'source' in source
        assert 'fps' in source
        assert source['fps']['value'] == 30
        test_logger.info("✅ Sources section correct")
        
        # Check controller section
        assert 'controller' in config
        assert config['controller']['fps'] == 30
        assert config['controller']['use_database'] == False
        test_logger.info("✅ Controller section correct")
        
        # Check other sections
        assert 'objects_handler' in config
        assert 'events_detectors' in config
        assert 'database' in config
        assert 'visualizer' in config
        test_logger.info("✅ All required sections present")
        
        # Check visualizer text_config
        assert 'text_config' in config['visualizer']
        text_config = config['visualizer']['text_config']
        assert 'font_size_pt' in text_config
        assert 'font_face' in text_config
        assert 'color' in text_config
        test_logger.info("✅ Text configuration present")
        
        test_logger.info("✅ PipelineCapture configuration test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in configuration test: {e}")
        import traceback
        traceback.print_exc()

def test_pipeline_capture_usage():
    """Test PipelineCapture usage with configuration."""
    
    test_logger.info("\n🔍 Testing PipelineCapture Usage")
    test_logger.info("=" * 60)
    
    try:
        from evileye.pipelines.pipeline_capture import PipelineCapture
        
        # Create pipeline
        pipeline = PipelineCapture()
        test_logger.info("✅ PipelineCapture created")
        
        # Load configuration
        config_path = "evileye/samples_configs/pipeline_capture.json"
        with open(config_path, 'r') as f:
            config = json.load(f)
        
        # Set pipeline parameters
        pipeline.params = config['pipeline']
        pipeline.set_params_impl()
        
        assert pipeline.video_path == "videos/sample_video.mp4"
        assert pipeline.fps == 30
        test_logger.info("✅ Configuration applied successfully")
        
        # Test default structure generation
        default_structure = pipeline.generate_default_structure(1)
        assert 'pipeline' in default_structure
        assert default_structure['pipeline']['pipeline_class'] == 'PipelineCapture'
        test_logger.info("✅ Default structure generation working")
        
        test_logger.info("✅ PipelineCapture usage test completed successfully")
        
    except Exception as e:
        test_logger.error(f"❌ Error in usage test: {e}")
        import traceback
        traceback.print_exc()

def main():
    """Main test function."""
    
    test_logger.info("🔍 PipelineCapture Configuration Test")
    test_logger.info("=" * 60)
    
    test_pipeline_capture_config()
    test_pipeline_capture_usage()
    
    test_logger.info("\n📋 Summary:")
    test_logger.info("  ✅ Configuration file structure correct")
    test_logger.info("  ✅ All required sections present")
    test_logger.info("  ✅ PipelineCapture can load configuration")
    test_logger.info("  ✅ Default structure generation working")
    test_logger.info("  ✅ All tests passed successfully")

if __name__ == "__main__":
    main()






#!/usr/bin/env python3
"""
Utility for downloading sample videos for EvilEye demonstrations.
"""

import os
import sys
import requests
from pathlib import Path
from tqdm import tqdm
import hashlib
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger

# Инициализация логирования
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
download_logger = get_module_logger("download_samples")

# Sample video URLs (public domain or free to use)
SAMPLE_VIDEOS = {
    "planes_sample.mp4": {
        "url": "https://github.com/aicommunity/EvilEye/releases/download/dev/planes_sample.mp4",
        "description": "Single video sample with planes and without",
        "md5": None  # Placeholder MD5
    },
    "sample_split.mp4": {
        "url": "https://github.com/aicommunity/EvilEye/releases/download/dev/sample_split.mp4", 
        "description": "Sample with two head camera video for splitting to two sources",
        "md5": None  # Placeholder MD5
    },
    "6p-c0.avi": {
        "url": "https://github.com/aicommunity/EvilEye/releases/download/dev/6p-c0.avi",
        "description": "Video for testing multi-camera tracking (camera 0)", 
        "md5": None  # Placeholder MD5
    },
    "6p-c1.avi": {
        "url": "https://github.com/aicommunity/EvilEye/releases/download/dev/6p-c1.avi",
        "description": "Video for testing multi-camera tracking (camera 1)", 
        "md5": None  # Placeholder MD5
    }
}


def download_file(url, filepath, description=""):
    """
    Download a file with progress bar.
    
    Args:
        url: URL to download from
        filepath: Local path to save file
        description: Description for progress bar
        
    Returns:
        bool: True if download successful, False otherwise
    """
    try:
        download_logger.info(f"Downloading {description}...")
        response = requests.get(url, stream=True)
        response.raise_for_status()
        
        total_size = int(response.headers.get('content-length', 0))
        
        with open(filepath, 'wb') as f:
            with tqdm(total=total_size, unit='B', unit_scale=True, desc=description) as pbar:
                for chunk in response.iter_content(chunk_size=8192):
                    if chunk:
                        f.write(chunk)
                        pbar.update(len(chunk))
        
        return True
        
    except Exception as e:
        download_logger.info(f"Error downloading {description}: {e}")
        return False

def verify_file(filepath, expected_md5=None):
    """
    Verify downloaded file integrity (optional).
    
    Args:
        filepath: Path to file to verify
        expected_md5: Expected MD5 hash (optional)
        
    Returns:
        bool: True if file exists and MD5 matches (if provided)
    """
    if not os.path.exists(filepath):
        return False
    
    if expected_md5:
        with open(filepath, 'rb') as f:
            file_md5 = hashlib.md5(f.read()).hexdigest()
        return file_md5 == expected_md5
    
    return True

def download_sample_videos(videos_dir="videos", force=False):
    """
    Download sample videos for EvilEye demonstrations.
    
    Args:
        videos_dir: Directory to save videos
        force: Force re-download even if files exist
        
    Returns:
        dict: Status of each video download
    """
    videos_path = Path(videos_dir)
    videos_path.mkdir(exist_ok=True)
    
    results = {}
    
    for filename, video_info in SAMPLE_VIDEOS.items():
        filepath = videos_path / filename
        
        # Skip if file exists and not forcing re-download
        if filepath.exists() and not force:
             download_logger.info(f"{filename} already exists, skipping...")
            results[filename] = {"status": "exists", "path": str(filepath)}
            continue
        
        # Try primary URL first
        success = download_file(
            video_info["url"], 
            filepath, 
            video_info["description"]
        )
        
        if success and verify_file(filepath, video_info.get("md5")):
            results[filename] = {"status": "downloaded", "path": str(filepath)}
             download_logger.info(f"Successfully downloaded {filename}")
        else:
            results[filename] = {"status": "failed", "path": str(filepath)}
             download_logger.info(f"Failed to download {filename}")
    
    return results

def main():
    """Main function for command line usage."""
    import argparse
    
    parser = argparse.ArgumentParser(description="Download sample videos for EvilEye")
    parser.add_argument("--videos-dir", default="videos", help="Directory to save videos")
    parser.add_argument("--force", action="store_true", help="Force re-download existing files")
    
    args = parser.parse_args()
    
     download_logger.info("EvilEye Sample Videos Downloader")
    download_logger.info("=" * 40)
    
    results = download_sample_videos(args.videos_dir, args.force)
    
     download_logger.info("\nDownload Summary:")
    download_logger.info("-" * 20)
    
     for filename, result in results.items():
         download_logger.info(f"{filename}: {result['status']}")
    
    successful = sum(1 for r in results.values() if "downloaded" in r["status"] or r["status"] == "exists")
    total = len(results)
    
     download_logger.info(f"\nSuccessfully processed {successful}/{total} videos")
    
    if successful == total:
         download_logger.info("All sample videos are ready!")
        return 0
    else:
         download_logger.info("Some videos failed to download. Check your internet connection.")
        return 1

if __name__ == "__main__":
    sys.exit(main())



"""
EvilEye - Intelligence video surveillance system

A comprehensive video surveillance system with object detection, tracking,
and multi-camera support.
"""

__version__ = "1.0.0"
__author__ = "EvilEye Team"
__email__ = "team@evileye.com"

# Инициализация логирования для пакета
from .core.logging_config import setup_evileye_logging
from .core.logger import get_module_logger

# Инициализация логирования
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
package_logger = get_module_logger("evileye_package")

# Import core components
from .core import PipelineProcessors, ProcessorBase, ProcessorSource, ProcessorFrame, ProcessorStep
from .pipelines import PipelineSurveillance

# Import registered classes
from .capture import video_capture
from .object_detector import object_detection_yolo
from .object_tracker import object_tracking_botsort
from .object_multi_camera_tracker import ObjectMultiCameraTracking

# Import main modules
from . import process
from . import configure
from . import controller

# Define public API
__all__ = [
    # Core components
    "Pipeline",
    "ProcessorBase", 
    "ProcessorSource",
    "ProcessorFrame",
    "ProcessorStep",
    "PipelineSurveillance",
    
    # Registered classes
    "video_capture",
    "object_detection_yolo", 
    "object_tracking_botsort",
    "ObjectMultiCameraTracking",
    
    # Main modules
    "process",
    "configure", 
    "controller",
]

# Auto-fix entry points on first import
def _auto_fix_entry_points():
    """Automatically fix entry points when package is imported"""
    import os
    import subprocess
    from pathlib import Path
    
    # Only run once per session
    if hasattr(_auto_fix_entry_points, '_run'):
        return
    _auto_fix_entry_points._run = True
    
    try:
        # Get the project root directory
        package_dir = Path(__file__).parent
        project_root = package_dir.parent
        fix_script = project_root / "fix_entry_points.sh"
        
        if fix_script.exists() and os.access(fix_script, os.X_OK):
            # Run the fix script silently
            result = subprocess.run(
                [str(fix_script)],
                cwd=project_root,
                capture_output=True,
                text=True,
                timeout=30  # 30 second timeout
            )
            
            if result.returncode == 0:
                package_logger.info("EvilEye entry points automatically fixed")
            else:
                package_logger.info(f"Warning: Could not auto-fix entry points: {result.stderr}")
                
    except Exception as e:
        # Don't fail the import if fixing fails
        pass

# Call auto-fix function (only if not imported as module)
if __name__ != "__main__":
    _auto_fix_entry_points()



import copy
import json
import os.path
from ....core.logger import get_module_logger
try:
    from PyQt6 import QtGui
    from PyQt6.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea,
        QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem,
        QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    from PyQt6.QtGui import QIcon
    from PyQt6.QtGui import QAction
    from PyQt6.QtCore import pyqtSignal, pyqtSlot, Qt
    pyqt_version = 6
except ImportError:
    from PyQt5 import QtGui
    from PyQt5.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea,
        QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem,
        QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    from PyQt5.QtGui import QIcon
    from PyQt5.QtGui import QAction
    from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt
    pyqt_version = 5
from evileye.utils import utils
import sys
from evileye.capture.video_capture_base import CaptureDeviceType
from evileye.capture import VideoCapture
from evileye.visualization_modules.configurer import parameters_processing
from evileye.visualization_modules.configurer.configurer_tabs.tracker_widget import TrackerWidget


class TrackerTab(QWidget):
    def __init__(self, config_params):
        super().__init__()

        self.params = config_params
        self.default_track_params = self.params[0]
        self.config_result = copy.deepcopy(config_params)

        self.proj_root = utils.get_project_root()
        self.hor_layouts = []
        self.layout_check_boxes = {}
        self.botsort_check_boxes = []
        self.src_counter = 0
        self.buttons_layouts_number = {}
        self.widgets_counter = 0
        self.layouts_counter = 0

        self.trackers = []
        self.track_tabs = QTabWidget()
        self.track_tabs.setTabsClosable(True)
        self.track_tabs.tabCloseRequested.connect(self._remove_tab)

        for params in self.params:
            new_tracker = TrackerWidget(params=params)
            self.trackers.append(new_tracker)
            self.track_tabs.addTab(new_tracker, f'Tracker{len(self.trackers) - 1}')

        self.vertical_layout = QVBoxLayout()
        self.vertical_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self.label = QLabel('To add a tracker you must add a detector first')
        self.vertical_layout.addWidget(self.label)

        self.button_layout = QHBoxLayout()
        self.button_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self.add_track_btn = QPushButton('Add tracker')
        self.add_track_btn.setMinimumWidth(200)
        self.add_track_btn.setEnabled(False)
        self.add_track_btn.clicked.connect(self._add_tracker)
        self.duplicate_track_btn = QPushButton('Duplicate tracker')
        self.duplicate_track_btn.setMinimumWidth(200)
        self.duplicate_track_btn.clicked.connect(self._duplicate_tracker)
        self.delete_track_btn = QPushButton('Delete tracker')
        self.delete_track_btn.setMinimumWidth(200)
        self.delete_track_btn.clicked.connect(self._delete_tracker)
        self.button_layout.addWidget(self.add_track_btn)
        self.button_layout.addWidget(self.duplicate_track_btn)
        self.button_layout.addWidget(self.delete_track_btn)

        self.vertical_layout.addLayout(self.button_layout)
        self.setLayout(self.vertical_layout)

        if len(self.trackers) > 0:
            self.enable_add_tracker_button()

    @pyqtSlot()
    def _duplicate_tracker(self):
        cur_tab = self.track_tabs.currentWidget()
        new_params = copy.deepcopy(cur_tab.get_dict())
        new_tracker = TrackerWidget(new_params)
        self.trackers.append(new_tracker)
        self.track_tabs.addTab(new_tracker, f'Tracker{len(self.trackers) - 1}')

    @pyqtSlot()
    def _delete_tracker(self):
        tab_idx = self.track_tabs.currentIndex()
        self.track_tabs.tabCloseRequested.emit(tab_idx)

    @pyqtSlot(int)
    def _remove_tab(self, idx):
        self.track_tabs.removeTab(idx)
        self.trackers.pop(idx)

    @pyqtSlot()
    def enable_add_tracker_button(self):
        self.add_track_btn.setEnabled(True)
        self.label.hide()
        self.vertical_layout.removeWidget(self.label)
        self.vertical_layout.insertWidget(0, self.track_tabs)

    @pyqtSlot()
    def _add_tracker(self):
        new_params = {key: '' for key in self.default_track_params.keys()}
        new_params['botsort_cfg'] = {key: '' for key in self.default_track_params['botsort_cfg'].keys()}
        # print(new_params)
        new_tracker = TrackerWidget(new_params)
        self.trackers.append(new_tracker)
        self.track_tabs.addTab(new_tracker, f'Tracker{len(self.trackers) - 1}')

    def get_forms(self) -> list[QFormLayout]:
        forms = []
        for tab_idx in range(self.track_tabs.count()):
            tab = self.track_tabs.widget(tab_idx)
            forms.append(tab.get_form())
        # print(forms)
        return forms

    def get_params(self):
        tracker_params = []
        for tab_idx in range(self.track_tabs.count()):
            tab = self.track_tabs.widget(tab_idx)
            tracker_params.append(tab.get_dict())
        return tracker_params



#!/usr/bin/env python3

import sys
import os
from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
sys.path.append('.')

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_image_paths():
    """Test image paths in journal"""
    
    test_logger.info("=== Test Image Paths ===")
    
    try:
        from evileye.visualization_modules.journal_data_source_json import JsonLabelJournalDataSource
        
        ds = JsonLabelJournalDataSource('EvilEyeData')
        
        # Get sample data
        events = ds.fetch(0, 5, {}, [])
        
        test_logger.info(f"\n📊 Image Paths Test:")
        for i, ev in enumerate(events):
            test_logger.info(f"   Event {i+1}:")
            test_logger.info(f"     Type: {ev.get('event_type')}")
            test_logger.info(f"     Object ID: {ev.get('object_id')}")
            test_logger.info(f"     Image filename: {ev.get('image_filename')}")
            test_logger.info(f"     Date folder: {ev.get('date_folder')}")
            
            # Test full path
            if ev.get('image_filename') and ev.get('date_folder'):
                full_path = os.path.join('EvilEyeData', 'images', ev.get('date_folder'), ev.get('image_filename'))
                exists = os.path.exists(full_path)
                test_logger.info(f"     Full path: {full_path}")
                test_logger.info(f"     Exists: {exists}")
                
                # Check if directory exists
                dir_path = os.path.join('EvilEyeData', 'images', ev.get('date_folder'))
                dir_exists = os.path.exists(dir_path)
                test_logger.info(f"     Directory exists: {dir_exists}")
                
                if dir_exists:
                    # List files in directory
                    try:
                        files = os.listdir(dir_path)
                        test_logger.info(f"     Files in directory: {len(files)}")
                        if len(files) > 0:
                            test_logger.info(f"     Sample files: {files[:3]}")
                    except Exception as e:
                        test_logger.info(f"     Error listing directory: {e}")
        
        ds.close()
        
    except Exception as e:
        test_logger.error(f"❌ Error: {e}")
        import traceback
        traceback.print_exc()

if __name__ == "__main__":
    test_image_paths()




from evileye.core.logging_config import setup_evileye_logging
from evileye.core.logger import get_module_logger
#!/usr/bin/env python3
"""
Debug script to analyze PreprocessingPipeline registration issue.
"""

import sys
from pathlib import Path

# Инициализация логирования для тестов
logger = setup_evileye_logging(log_level="INFO", log_to_console=True, log_to_file=True)
test_logger = get_module_logger("test")

def test_registry_debug():
    """Debug registry registration."""
    
    test_logger.info("🔍 Debug Registry Registration")
    test_logger.info("=" * 60)
    
    # Clear registry
    from evileye.core.base_class import EvilEyeBase
    EvilEyeBase._registry.clear()
    test_logger.info("Registry cleared")
    
    # Check registry before any imports
    test_logger.info(f"Registry before imports: {len(EvilEyeBase._registry)} items")
    
    # Import preprocessing step by step
    try:
        test_logger.info("1. Importing preprocessing_base...")
        import evileye.preprocessing.preprocessing_base
        test_logger.info(f"   Registry after preprocessing_base: {len(EvilEyeBase._registry)} items")
        
        test_logger.info("2. Importing preprocessing_factory...")
        import evileye.preprocessing.preprocessing_factory
        test_logger.info(f"   Registry after preprocessing_factory: {len(EvilEyeBase._registry)} items")
        
        test_logger.info("3. Importing preprocessing_vehicle...")
        import evileye.preprocessing.preprocessing_vehicle
        test_logger.info(f"   Registry after preprocessing_vehicle: {len(EvilEyeBase._registry)} items")
        
        # Check if PreprocessingPipeline is registered
        if "PreprocessingPipeline" in EvilEyeBase._registry:
            test_logger.info("✅ PreprocessingPipeline is registered!")
        else:
            test_logger.info("❌ PreprocessingPipeline is NOT registered!")
            
        # Show all registered classes
        test_logger.info("\nRegistered classes:")
        for name, cls in EvilEyeBase._registry.items():
            test_logger.info(f"  {name}: {cls}")
            
    except Exception as e:
        test_logger.error(f"❌ Error during step-by-step import: {e}")
        import traceback
        traceback.print_exc()

def test_import_evileye_preprocessing():
    """Test importing evileye.preprocessing directly."""
    
    test_logger.info("\n🔍 Test Import evileye.preprocessing")
    test_logger.info("=" * 60)
    
    # Clear registry
    from evileye.core.base_class import EvilEyeBase
    EvilEyeBase._registry.clear()
    test_logger.info("Registry cleared")
    
    try:
        test_logger.info("Importing evileye.preprocessing...")
        import evileye.preprocessing
        test_logger.info(f"Registry after import: {len(EvilEyeBase._registry)} items")
        
        if "PreprocessingPipeline" in EvilEyeBase._registry:
            test_logger.info("✅ PreprocessingPipeline is registered!")
        else:
            test_logger.info("❌ PreprocessingPipeline is NOT registered!")
            
    except Exception as e:
        test_logger.error(f"❌ Error importing evileye.preprocessing: {e}")
        import traceback
        traceback.print_exc()

def main():
    """Main debug function."""
    
    test_logger.info("🔍 PreprocessingPipeline Registration Debug")
    test_logger.info("=" * 60)
    
    test_registry_debug()
    test_import_evileye_preprocessing()

if __name__ == "__main__":
    main()



import copy
import json
import os.path
try:
    from PyQt6 import QtGui
    from PyQt6.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea,
        QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem,
        QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    from PyQt6.QtGui import QIcon
    from PyQt6.QtGui import QAction
    from PyQt6.QtCore import pyqtSignal, pyqtSlot, Qt
    pyqt_version = 6
except ImportError:
    from PyQt5 import QtGui
    from PyQt5.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea,
        QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem,
        QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    from PyQt5.QtGui import QIcon
    from PyQt5.QtGui import QAction
    from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt
    pyqt_version = 5
from evileye.utils import utils
import sys
from evileye.capture.video_capture_base import CaptureDeviceType
from evileye.capture import VideoCapture
from evileye.visualization_modules.configurer import parameters_processing


class VisualizerTab(QWidget):
    def __init__(self, config_params):
        super().__init__()

        self.params = config_params
        self.default_src_params = self.params['visualizer']
        self.config_result = copy.deepcopy(config_params)

        self.proj_root = utils.get_project_root()
        self.hor_layouts = {}
        self.split_check_boxes = []
        self.botsort_check_boxes = []
        self.coords_edits = []
        self.src_counter = 0

        self.line_edit_param = {}  # Словарь для сопоставления полей интерфейса с полями json-файла

        self.vertical_layout = QVBoxLayout()
        # self.vertical_layout.setAlignment(Qt.AlignmentFlag.AlignLeft | Qt.AlignmentFlag.AlignTop)
        self.vertical_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self._setup_layout()
        self.setLayout(self.vertical_layout)

    def _setup_layout(self):
        self.vertical_layout.setContentsMargins(10, 10, 10, 10)

        visualizer_layout = self._setup_visualizer_form()
        self.vertical_layout.addLayout(visualizer_layout)

    def _setup_visualizer_form(self):
        layout = QFormLayout()

        name = QLabel('Visualizer Parameters')
        layout.addWidget(name)

        num_width = QLineEdit()
        layout.addRow('Number of cameras in width', num_width)
        self.line_edit_param['num_width'] = num_width

        num_height = QLineEdit()
        layout.addRow('Number of cameras in height', num_height)
        self.line_edit_param['num_height'] = num_height

        visual_buffer = QLineEdit()
        layout.addRow('Visual buffer size', visual_buffer)
        self.line_edit_param['visual_buffer_num_frames'] = visual_buffer

        source_ids = QLineEdit()
        source_ids.setText('[Sources]')
        layout.addRow('Visualized sources', source_ids)
        self.line_edit_param['source_ids'] = source_ids

        fps_sources = QLineEdit()
        fps_sources.setText('[Sources fps]')
        layout.addRow('Sources fps', fps_sources)
        self.line_edit_param['fps'] = fps_sources

        gui_enabled = QCheckBox()
        layout.addRow('GUI Enabled', gui_enabled)
        self.line_edit_param['gui_enabled'] = gui_enabled

        show_debug_info = QCheckBox()
        layout.addRow('Show debug information', show_debug_info)
        self.line_edit_param['show_debug_info'] = show_debug_info

        objects_journal_enabled = QCheckBox()
        layout.addRow('Objects journal enabled', objects_journal_enabled)
        self.line_edit_param['objects_journal_enabled'] = objects_journal_enabled

        widgets = (layout.itemAt(i).widget() for i in range(layout.count()))
        for widget in widgets:
            widget.setSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed)
            widget.setMinimumWidth(200)
        return layout

    def get_forms(self) -> list[QFormLayout]:
        form_layouts = []
        forms = [form for i in range(self.vertical_layout.count()) if isinstance(form := self.vertical_layout.itemAt(i), QFormLayout)]
        form_layouts.extend(forms)
        return form_layouts

    def get_params(self):
        res_dict = self._create_dict()
        return res_dict

    def _create_dict(self):
        vis_params = {}

        widget = self.line_edit_param['num_width']
        vis_params['num_width'] = parameters_processing.process_numeric_types(widget.text())

        widget = self.line_edit_param['num_height']
        vis_params['num_height'] = parameters_processing.process_numeric_types(widget.text())

        widget = self.line_edit_param['visual_buffer_num_frames']
        vis_params['visual_buffer_num_frames'] = parameters_processing.process_numeric_types(widget.text())

        widget = self.line_edit_param['source_ids']
        vis_params['source_ids'] = parameters_processing.process_numeric_lists(widget.text())

        widget = self.line_edit_param['fps']
        vis_params['fps'] = parameters_processing.process_numeric_lists(widget.text())

        widget = self.line_edit_param['gui_enabled']
        vis_params['gui_enabled'] = True if widget.isChecked() else False

        widget = self.line_edit_param['show_debug_info']
        vis_params['show_debug_info'] = True if widget.isChecked() else False

        widget = self.line_edit_param['objects_journal_enabled']
        vis_params['objects_journal_enabled'] = True if widget.isChecked() else False

        return vis_params



import copy
try:
    from PyQt6.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea,
        QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem,
        QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    from PyQt6.QtCore import pyqtSignal, pyqtSlot, Qt
    pyqt_version = 6
except ImportError:
    from PyQt5.QtWidgets import (
        QWidget, QLabel, QVBoxLayout, QHBoxLayout, QLineEdit, QScrollArea,
        QSizePolicy, QToolBar, QComboBox, QFormLayout, QSpacerItem,
        QMenu, QMainWindow, QApplication, QCheckBox, QPushButton, QTabWidget
    )
    from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt
    pyqt_version = 5
from evileye.utils import utils
from evileye.visualization_modules.configurer import parameters_processing


class HandlerTab(QWidget):
    def __init__(self, config_params, database_params):
        super().__init__()

        self.params = config_params
        self.database_params = database_params
        self.default_src_params = self.database_params['database']
        self.config_result = copy.deepcopy(config_params)

        self.proj_root = utils.get_project_root()
        self.split_check_boxes = []
        self.botsort_check_boxes = []
        self.coords_edits = []
        self.src_counter = 0

        self.line_edit_param = {}  # Словарь для сопоставления полей интерфейса с полями json-файла

        self.vertical_layout = QVBoxLayout()
        self.vertical_layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
        self._setup_layout()
        self.setLayout(self.vertical_layout)

    def _setup_layout(self):
        self.vertical_layout.setContentsMargins(10, 10, 10, 10)

        handler_layout = self._setup_handler_form()
        self.vertical_layout.addLayout(handler_layout)

    def _setup_handler_form(self):
        layout = QFormLayout()

        name = QLabel('Handler Parameters')
        layout.addWidget(name)

        history_len = QLineEdit()
        history_len.setText('30')
        layout.addRow('History length', history_len)
        self.line_edit_param['history_len'] = history_len

        lost_store_time_secs = QLineEdit()
        lost_store_time_secs.setText('60')
        layout.addRow('Lost objects store time', lost_store_time_secs)
        self.line_edit_param['lost_store_time_secs'] = lost_store_time_secs

        lost_thresh = QLineEdit()
        lost_thresh.setText('5')
        layout.addRow('Lost threshold', lost_thresh)
        self.line_edit_param['lost_thresh'] = lost_thresh

        widgets = (layout.itemAt(i).widget() for i in range(layout.count()))
        for widget in widgets:
            widget.setSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed)
            widget.setMinimumWidth(200)
        return layout

    def get_forms(self) -> list[QFormLayout]:
        form_layouts = []
        forms = [form for i in range(self.vertical_layout.count()) if isinstance(form := self.vertical_layout.itemAt(i), QFormLayout)]
        form_layouts.extend(forms)
        return form_layouts

    def get_params(self):
        res_dict = self._create_dict()
        return res_dict

    def _create_dict(self):
        hand_params = {}

        widget = self.line_edit_param['history_len']
        hand_params['history_len'] = parameters_processing.process_numeric_types(widget.text())

        widget = self.line_edit_param['lost_store_time_secs']
        hand_params['lost_store_time_secs'] = parameters_processing.process_numeric_types(widget.text())

        widget = self.line_edit_param['lost_thresh']
        hand_params['lost_thresh'] = parameters_processing.process_numeric_types(widget.text())

        return hand_params
